package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(``P`!````,)D$"#0```"\OP```````#0`(``(
M`"@`'``;``8````T````-(`$"#2`!`@``0````$```4````$`````P```#0!
M```T@00(-($$"!,````3````!`````$````!``````````"`!`@`@`0($+L`
M`!"[```%`````!````$````0NP``$$L%"!!+!0B$`@``U!(```8`````$```
M`@```"2[```D2P4()$L%"!`!```0`0``!@````0````$````2`$``$B!!`A(
M@00(1````$0````$````!````%#E=&0PN@``,#H%"#`Z!0@T````-`````0`
M```$````4>5T9```````````````````````````!@````0````O;&EB+VQD
M+6QI;G5X+G-O+C(```0````0`````0```$=.50```````@````8````2````
M!````!0````#````1TY5`,L5>'I]=VDL]8./CT4]8#9?EC?-)0```$T````(
M````"``````0$`0E0`2`J!$``:*&0:A````"2R@$*3BB,D>*!`R(30```$\`
M``````````````````!2````5````%4`````````5@```%<`````````6```
M`%D```!:`````````%L```````````````````!<````7P``````````````
M8````&(```!C````90````````!G````:@````````!L````;0```&X```!O
M`````````,C5LG%9Z.WLYO\PHL[>1RVCX/M)ZM/O#J?=HVLOQ9NVV\WCGH?Y
MG(%K"4/6#3J7"\6)!9`-%.*>(?_D#K(!BV_$N9Q`:W^:?'^IG)MNQ=\?V7%8
M'+OCDGS49-1\K4OCP#)BV^WAIP(*9J_,9F`6R5E[\$IKXD?&`4-%U>Q'[#,Z
M?4&.Q</E/RSRV],=^J%L8+F-\0X`````````````````````*0,`````````
M````$@```'<#`````````````!(```"L```````````````2````M`,`````
M````````$@```)\#`````````````!(```"<`0`````````````2````=0(`
M````````````$@````P``````````````"`````;```````````````@````
MI0,`````````````$@```(@!`````````````!(```!4!``````````````2
M````:0$`````````````$@```'L!`````````````!(```"0`P``````````
M```2````8`,`````````````$@```#H#`````````````!(````G`@``````
M```````2````^```````````````$@```!<"`````````````!(```#0`P``
M```````````2````Q0$`````````````$@```#@$`````````````!(````(
M`P`````````````2````0@,`````````````$@```),"`````````````!(`
M``#E`0`````````````2````H0$`````````````$@```#`"````````````
M`!(```!>!``````````````2````*@0`````````````$@```"H!````````
M`````!(```#K`P`````````````2````+P``````````````$@```/,#````
M`````````!(```!8`0`````````````2````PP``````````````$@```!@$
M`````````````!(```#D`P`````````````2````$00`````````````$@``
M`,D#`````````````!(```"8`P`````````````2````004`````````````
M$@```#P!`````````````!(````!!``````````````2````5P(`````````
M````$@```(<#`````````````!(````<`P`````````````2````20(`````
M````````$@```-<#`````````````!(```",`@`````````````2````I@$`
M````````````$@```-X#`````````````!(```#"`P`````````````2````
MYP``````````````$@```#T``````````````!(````(!``````````````2
M````(@0`````````````$@```-(``````````````!(```#Y`0``````````
M```2````@`(`````````````$@```$L!`````````````!(```"M`P``````
M```````2````?P,`````````````$@```"(#`````````````!(````8`0``
M```````````2````/@(`````````````$@```$\``````````````!(```"[
M`P`````````````2````TP$`````````````$@```%X``````````````!(`
M```Q!``````````````2````B@``````````````$@```'(#````````````
M`!(```!S```````````````2````!@$`````````````$@```+(!``"XE`0(
M`````!(```#B!```8-L$"`0````1``\`JP4``,#@!`AN60``$0`/`+4%``")
MO00(*`8``!(`#0#A!0``H*($"+4!```2``T`W`0``"S;!`@`````$@`.`$P$
M``"@304(!````"$`&0"T!```#I\$"`T````2``T`>@4``"#:!`A:````$@`-
M`)L```"(E@0(`````!(```!E!0``?$T%"``````0`!@`9P4``'Q-!0@`````
M(``8`$L$``"@304(!````"$`&0#2!```$-H$"`4````2``T`U`4``!N?!`@I
M`@``$@`-`/\$``!5I`0(40```!(`#0!*!```H$T%"`0````1`!D`100``"#7
M!`BH`@``$@`-`"\%``!GNP0(-P```!(`#0!*!0``&L4$"&`````2``T`<`0`
M`)1-!0@`````$`#Q_WP$``#D704(`````!``\?_I!```(<@$"),.```2``T`
M40,``&3;!`@$````$0`/`&L%```PF00(`````!(`#0`-!0``3IX$",`````2
M``T`(P4``(:A!`@:`0``$@`-`%8%``"0304(!````!$`&`!E`@``>)8$"```
M```2````Q00``$2A!`A"````$@`-`&D$``"4304(`````!``\?^F!0``C$T%
M"`0````1`!@`B@4``,7'!`A<````$@`-`'(%``#DF00(1````!(`#0">`@``
MI$T%"!,````1`!D`P@4``%2\!`@U`0``$@`-`'0%```(E`0(`````!(`"P``
M;&EB<&5R;"YS;P!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S
M`%!E<FQ?<WES7W1E<FT`4&5R;%])<W1A=&)U9E]P='(`4&5R;%]S>7-?:6YI
M=#,`4&5R;%])97AI=%]F;&%G<U]P='(`4&5R;%]S879E7V1E<W1R=6-T;W)?
M>`!097)L7TEC;VUP8W9?<'1R`%!E<FQ?871F;W)K7VQO8VL`4&5R;%])8W5R
M<W1A8VMI;F9O7W!T<@!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K7VYO8V]N
M=&5X=`!097)L7TEP87)S97)?<'1R`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R
M<'9?9FQA9W,`4&5R;%])=&]P7V5N=E]P='(`4&5R;%])=&%I;G1E9%]P='(`
M4&5R;%]S=E]S971P=FX`4&5R;%]N97=35G!V`%!E<FQ?;F5W6%-?9FQA9W,`
M4&5R;%]):6Y?979A;%]P='(`4&5R;%]);W!?<'1R`%!E<FQ?265V86Q?<F]O
M=%]P='(`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C
M:P!097)L7W-V7W-E='!V`%!E<FQ?1W1H<E]K97E?<'1R`%!E<FQ?1V1O7W5N
M9'5M<%]P='(`4&5R;%])<&5R;%]D97-T<G5C=%]L979E;%]P='(`4&5R;%]G
M=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N97=84P!P
M97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E
M<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M
M;W)Y7W=R87``;&EB<F5S;VQV+G-O+C(`;&EB;G-L+G-O+C$`;&EB9&PN<V\N
M,@!L:6)M+G-O+C8`;&EB8W)Y<'0N<V\N,0!L:6)U=&EL+G-O+C$`;&EB<'1H
M<F5A9"YS;RXP`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E;C8T`%]?
M97)R;F]?;&]C871I;VX`;'-E96LV-`!R96%D`&QI8F,N<V\N-@!?24]?<W1D
M:6Y?=7-E9`!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-P<FEN=&8`<W1R;F-M
M<`!C;&]S961I<@!S=')N8W!Y`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H
M<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R
M;61I<@!M96UC<'D`;W!E;F1I<@!?7V-T>7!E7V)?;&]C`&=E='5I9`!R96%D
M;&EN:P!E>&5C=G``<F5A9&1I<C8T`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?
M7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`7U]X<W1A=#8T`%]?;'AS=&%T
M-C0`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`+W5S<B]L:6(O<&5R;#4O-2XQ
M,"XP+VDS.#8M;&EN=7@M=&AR96%D+6UU;'1I+T-/4D4`<&%R7V-U<G)E;G1?
M97AE8P!P87)?8F%S96YA;64`7U]L:6)C7V-S=5]F:6YI`%]F<%]H=P!84U])
M;G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E
M>&5C7W!R;V,`<&%R7V1I<FYA;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U
M:60`<&%R7V-L96%N=7``<VEZ95]L;V%D7VUE7S(`7U]D871A7W-T87)T`'AS
M7VEN:70`7U]L:6)C7V-S=5]I;FET`%A37TEN=&5R;F%L<U]005)?0TQ%05)3
M5$%#2P!N86UE7VQO861?;65?,@!P87)?;6MT;7!D:7(`<&%R7W-E='5P7VQI
M8G!A=&@`<&%R7V9I;F1P<F]G`'!A<E]I;FET7V5N=@!'3$E"0U\R+C,`1TQ)
M0D-?,BXS+C(`1TQ)0D-?,BXR`$=,24)#7S(N,`````(``P````,``P``````
M``````,````$```````#``4`!@`````````#`````P`"``(```````,````$
M``,````#````!P``````!``#``,``P`#``,````#`````P`"`````P`#````
M`P`#```````#``,````````````#``,`!@`````````#```````#`````P``
M```````!``$``0`!``$``P`!``$````!``$``P`!``$``0`#``$``0`!``$`
M`0`!``$``0`!``$``0````$``0`!``$``0````$``0`!``0`1P,``!````!0
M````$VEI#0``!P#N!0``$````'(9:0D```4`^`4``!`````2:6D-```$``0&
M```0````$&EI#0```P`.!@````````$``@#X`@``$``````````2:6D-```&
M``0&```0````$&EI#0```@`.!@```````#1,!0@&"```H$T%"`5=``"D304(
M!6\``$1,!0@'`0``2$P%"`<"``!,3`4(!P,``%!,!0@'!```5$P%"`<%``!8
M3`4(!P8``%Q,!0@'!P``8$P%"`=-``!D3`4(!P@``&A,!0@'"@``;$P%"`<+
M``!P3`4(!PP``'1,!0@'#0``>$P%"`<.``!\3`4(!P\``(!,!0@'$```A$P%
M"`<1``"(3`4(!Q(``(Q,!0@'$P``D$P%"`<4``"43`4(!Q4``)A,!0@'%@``
MG$P%"`<7``"@3`4(!Q@``*1,!0@'&0``J$P%"`<:``"L3`4(!QL``+!,!0@'
M'```M$P%"`<=``"X3`4(!QX``+Q,!0@''P``P$P%"`<@``#$3`4(!R$``,A,
M!0@'(@``S$P%"`<C``#03`4(!VD``-1,!0@'5@``V$P%"`<D``#<3`4(!R4`
M`.!,!0@')@``Y$P%"`<G``#H3`4(!R@``.Q,!0@'*0``\$P%"`<J``#T3`4(
M!RL``/A,!0@'+```_$P%"`<M````304(!RX```1-!0@'+P``"$T%"`<P```,
M304(!S$``!!-!0@',@``%$T%"`<S```8304(!S0``!Q-!0@'-0``($T%"`<V
M```D304(!S<``"A-!0@'.```+$T%"`<Y```P304(!SH``#1-!0@'.P``.$T%
M"`<\```\304(!ST``$!-!0@'/@``1$T%"`<_``!(304(!T```$Q-!0@'00``
M4$T%"`="``!4304(!T,``%A-!0@'1```7$T%"`=%``!@304(!T8``&1-!0@'
M1P``:$T%"`=(``!L304(!TD``'!-!0@'2@``=$T%"`=+``!X304(!TP``%6)
MY5.#[`3H`````%N!PR2X``"+D_S___^%TG0%Z)X```#HD04``.C,1@``6%O)
MP_\U/$P%"/\E0$P%"`````#_)41,!0AH`````.G@_____R5(3`4(:`@```#I
MT/____\E3$P%"&@0````Z<#_____)5!,!0AH&````.FP_____R543`4(:"``
M``#IH/____\E6$P%"&@H````Z9#_____)5Q,!0AH,````.F`_____R5@3`4(
M:#@```#I</____\E9$P%"&A`````Z6#_____)6A,!0AH2````.E0_____R5L
M3`4(:%````#I0/____\E<$P%"&A8````Z3#_____)71,!0AH8````.D@____
M_R5X3`4(:&@```#I$/____\E?$P%"&AP````Z0#_____)8!,!0AH>````.GP
M_O___R6$3`4(:(````#IX/[___\EB$P%"&B(````Z=#^____)8Q,!0AHD```
M`.G`_O___R603`4(:)@```#IL/[___\EE$P%"&B@````Z:#^____)9A,!0AH
MJ````.F0_O___R6<3`4(:+````#I@/[___\EH$P%"&BX````Z7#^____):1,
M!0AHP````.E@_O___R6H3`4(:,@```#I4/[___\EK$P%"&C0````Z4#^____
M);!,!0AHV````.DP_O___R6T3`4(:.````#I(/[___\EN$P%"&CH````Z1#^
M____);Q,!0AH\````.D`_O___R7`3`4(:/@```#I\/W___\EQ$P%"&@``0``
MZ>#]____)<A,!0AH"`$``.G0_?___R7,3`4(:!`!``#IP/W___\ET$P%"&@8
M`0``Z;#]____)=1,!0AH(`$``.F@_?___R783`4(:"@!``#ID/W___\EW$P%
M"&@P`0``Z8#]____)>!,!0AH.`$``.EP_?___R7D3`4(:$`!``#I8/W___\E
MZ$P%"&A(`0``Z5#]____)>Q,!0AH4`$``.E`_?___R7P3`4(:%@!``#I,/W_
M__\E]$P%"&A@`0``Z2#]____)?A,!0AH:`$``.D0_?___R7\3`4(:'`!``#I
M`/W___\E`$T%"&AX`0``Z?#\____)01-!0AH@`$``.G@_/___R4(304(:(@!
M``#IT/S___\E#$T%"&B0`0``Z<#\____)1!-!0AHF`$``.FP_/___R44304(
M:*`!``#IH/S___\E&$T%"&BH`0``Z9#\____)1Q-!0AHL`$``.F`_/___R4@
M304(:+@!``#I</S___\E)$T%"&C``0``Z6#\____)2A-!0AHR`$``.E0_/__
M_R4L304(:-`!``#I0/S___\E,$T%"&C8`0``Z3#\____)31-!0AHX`$``.D@
M_/___R4X304(:.@!``#I$/S___\E/$T%"&CP`0``Z0#\____)4!-!0AH^`$`
M`.GP^____R5$304(:``"``#IX/O___\E2$T%"&@(`@``Z=#[____)4Q-!0AH
M$`(``.G`^____R50304(:!@"``#IL/O___\E5$T%"&@@`@``Z:#[____)5A-
M!0AH*`(``.F0^____R5<304(:#`"``#I@/O___\E8$T%"&@X`@``Z7#[____
M)61-!0AH0`(``.E@^____R5H304(:$@"``#I4/O___\E;$T%"&A0`@``Z4#[
M____)7!-!0AH6`(``.DP^____R5T304(:&`"``#I(/O___\E>$T%"&AH`@``
MZ1#[__\``````````#'M7HGA@^3P4%12:!#:!`AH(-H$"%%6:"#7!`CH5_S_
M__20D)"0D)"0D)"0D)"0D%6)Y5.#[`2`/;A-!0@`=4&+%;Q-!0BX'$L%""T8
M2P4(P?@"C5C_.=IS((VV`````(/"`8D5O$T%"/\4E1A+!0B+%;Q-!0@YVG+F
MQ@6X304(`8/$!%M=PXGVC;PG`````%6)Y8/L&*$@2P4(A<!T$K@`````A<!T
M"<<$)"!+!0C_T,G#D%6)Y8/L*,=%]'#;!`C'!"0`````Z+O^__^+`(D$).BQ
M^___BU7TB50D#,=$)`AXE@0(QT0D!'K;!`B)!"3H8O[__\G#58GE4X'L)!``
M`+B6VP0(QT0D"/\/``"-E?3O__^)5"0$B00DZ)?]__^)1?2#??0`?A:+1?2#
MZ`$/MH0%].___X3`=02#;?0!@WWT`'Y9BT7TB40D",=$)`0O````C87T[___
MB00DZ+7]__^%P'0XBUWTQP0D`````.@2_O__BP")!"3H"/O__XE<)`R-E?3O
M__^)5"0(BU4,B50D!(D$).A+_/__ZRS'!"0`````Z-W]__^+`(D$).C3^O__
MBU40B50D"(M5#(E4)`2)!"3HG?K__X'$)!```%M=PU6)Y8/L*(-]"`!T":&@
M304(A<!U"K@`````Z9T```"+10B)1>SK!(-%[`&+1>P/M@"$P'0*BT7L#[8`
M/#UUZ(M5[(M%"(G1*<&)R(E%Z*&@304(B47PZU&+1>B)1"0(BT4(B40D!(M%
M](D$).CC_/__A<!U,(M%Z`-%]`^V`#P]=2.+5?"AH$T%"(G1*<&)R,'X`HG"
MBT4,B1"+1>B#P`$#1?3K%X-%\`2+1?"+`(E%](-]]`!UH;@`````R<-5B>6#
M["B-1?2)1"0$BT4(B00DZ"K____)PU6)Y5.#[#2+10P/M@`\/74$@T4,`8M%
M#(D$).CL^O__B47LC47DB40D!(M%"(D$).CS_O__B47H@WWH`'1`BT7HB00D
MZ,/Z__\[1>P/@@0!``"+10P/MA"+1>B($(M%Z`^V`(3`#Y7`@T7H`8-%#`&$
MP'7>N`````#IH0$``*&@304(B47TQT7P`````.L(@T7T!(-%\`&+1?2+`(7`
M=>^AX%T%"(7`=#2+1?"#P`+!X`*)PJ&@304(B50D!(D$).@W^/__HZ!-!0BA
MH$T%"(7`=62X_____^E"`0``QP7@704(`0```(M%\(/``L'@`HD$).BT^O__
MB47T@WWT`'4*N/_____I%`$``(M%\(T4A0````"AH$T%"(E4)`B)1"0$BT7T
MB00DZ._Z__^+1?2CH$T%".L!D*&@304(BU7P@\(!P>("`=#'``````"+1?")
M1>3K`9"+10B)1>CK!(-%Z`&+1>@/M@"$P'0*BT7H#[8`/#UUZ*&@304(BU7D
MP>("C1P0BU7HBT4(B=$IP8G(`T7L@\`"B00DZ`WZ__^)`XL#A<!U![C_____
MZW&AH$T%"(M5Y,'B`@'0BP")1>CK!(-%Z`&+10@/MA"+1>B($(M%Z`^V`(3`
M#Y7`@T4(`83`=`J+1>@/M@`\/774BT7HQ@`]@T7H`8M%#`^V$(M%Z(@0BT7H
M#[8`A,`/E<"#1>@!@T4,`83`==ZX`````(/$-%M=PU6)Y8/L*.LMH:!-!0B+
M5?#!X@(!T(E%](M%](/`!(L0BT7TB1"+1?2+`(7`=`:#1?0$Z^20C47PB40D
M!(M%"(D$).B\_/__A<!UO<G#58GE@>PH(```QT7P`````.@5]O__NJG;!`C'
M1"0,M=L$"(E$)`B)5"0$C87O[___B00DZ-+U__^)1?2#??0`>0>X`````.MV
MC87O[___QT0D"``0``"-E>[?__^)5"0$B00DZ#+Y__^)1?2#??0`>0>X````
M`.M&BT7T@\`!B00DZ+3X__^)1?"#??``=0>X`````.LHBT7TB40D"(V%[M__
M_XE$)`2+1?")!"3HR/?__XM%]`-%\,8``(M%\,G#58GE@^P(Z#7____)PU6)
MY8'L.!```,<$)+G;!`CHDOS__XE%]*&`304(B40D!(M%"(D$).@Q^/__A<!T
M&XM%"(E$)`3'!"3"VP0(Z'[\__^+10CIW`$``(M%"(D$).AW]___B47LH81-
M!0B)1"0$BT4,B00DZ##X__^)1>CID@$``(M%Z`^V`(3`=0?'1>C/VP0(@WWT
M`'0SBT7HB40D!(M%](D$).@?^?__A<!U':&$304(B40D!,<$)`````#HYO?_
M_XE%Z.E(`0``BT7HB00DZ`/W__^)1?#K#8-M\`&+1?`#1>C&``"+1?"#Z`$#
M1>@/MA"A@$T%"`^V`#C"=-N+1?"#P`$#1>P]_P\``'X;BT4(B40D!,<$),+;
M!`CHJOO__XM%".D(`0``BQ6`304(N-';!`B+30B)3"00B50D#(M5Z(E4)`B)
M1"0$C87H[___B00DZ._S___'!"0`````Z$/X__^+`(D$).@Y]?__B00DZ%'W
M__^-E>CO__^)1"0$B10DZ.<Y``"%P'5MQP0D`````.@/^/__BP")!"3H!?7_
M_XD$).@=]___BT`0)0#P```]`(```'5`QT0D!`$```"-A>CO__^)!"3H2/7_
M_X7`=2:-A>CO__^)1"0$QP0DPML$".CB^O__C87H[___B00DZ*#W___K.*&$
M304(B40D!,<$)`````#HF?;__XE%Z(-]Z``/A63^__^+10B)1"0$QP0DPML$
M".B=^O__BT4(R<-5B>6#[!"+10B)1?B+10B)1?SK'XM%_`^V$*&`304(#[8`
M.,)U"8M%_(/``8E%^(-%_`&+1?P/M@"$P'77BT7XR<-5B>6#["B#?0@`=`J+
M10@/M@"$P'41QP0DS]L$".@`]___Z?$```"+10B)!"3H,/7__X/H`0-%"(E%
M].L$@VWT`8M%]#M%"'88BT7T#[80H8!-!0@/M@`XPG3BZP2#;?0!BT7T.T4(
M=A*+1?0/MA"A@$T%"`^V`#C"=>*+1?0[10AU+XM%]`^V$*&`304(#[8`.,)U
M#L<$),_;!`CH@?;__^MUH8!-!0B)!"3H<O;__^MF@VWT`8M%]#M%"'82BT7T
M#[80H8!-!0@/M@`XPG3BBU7TBT4(B=$IP8G(@\`"/0`0``!V![@`````ZRN+
M5?2+10B)T2G!B<B#P`&)1"0(BT4(B40D!,<$).!-!0CHC_+__[C@304(R<-5
MB>6#[$BAA-P$"(E%TJ&(W`0(B476H8S<!`B)1=JAD-P$"(E%WJ&4W`0(B47B
MH9C<!`B)1>:AG-P$"(E%ZJ&@W`0(B47N#[<%I-P$"&:)1?+'!"38VP0(Z`3[
M___'!"3HVP0(Z/CZ___'!"2YVP0(Z.SZ___'!"3TVP0(Z.#Z___'!"3^VP0(
MZ-3Z___'!"0(W`0(Z,CZ___'!"3"VP0(Z+SZ___'!"02W`0(Z+#Z___'!"0;
MW`0(Z*3Z___'!"0FW`0(Z%GX__^)1?2#??0`=!.+1?2)1"0$QP0D_ML$".A7
M^/__QP0D-]P$".@Q^/__B47T@WWT`'03BT7TB40D!,<$)$G<!`CH+_C__\<$
M)%3<!`CH"?C__XE%](-]]`!T%8M%](E$)`3'!"2YVP0(Z`?X___K:,<$)&3<
M!`CHW_?__XE%](-]]`!T%8M%](E$)`3'!"3TVP0(Z-WW___K/HU%TH/`$8E%
M],=$)`@*````QT0D!'7<!`B+1?2)!"3H,_3__X7`=1:+1?2#P`J)1"0$QP0D
M]-L$".B=]___QT0D!(#<!`C'!"38VP0(Z(GW___)PU6)Y8/L**&(304(@_C_
M=3K'!"3TVP0(Z%'W__^)1?2#??0`=!N+1?0/M@"$P'01BT7T#[8`/#!T![@!
M````ZP6X`````*.(304(H8A-!0C)PU6)Y5.!['`!``"+10B#P!R)1=S'1=@`
M````ZT:+1=R+`(E%X(-%W`2+1=B+5>")T<'A&(M5X,'B"('B``#_``G1BU7@
MP>H(@>(`_P``"=&+5>#!ZA@)RHF4A9C^__^#1=@!@WW8#WZTQT78$````.M?
MBT78BU78@^H#BXR5F/[__XM5V(/J"(N4E9C^__\QT8M5V(/J#HN4E9C^__\Q
MT8M5V(/J$(N4E9C^__\QRHF4A9C^__^+1=B+5=B+E)68_O__P<H?B92%F/[_
M_X-%V`&#?=A/?IN+10B+`(E%Y(M%"(M`!(E%Z(M%"(M`"(E%[(M%"(M`#(E%
M\(M%"(M`$(E%](V%F/[__XE%^(M%Y(G!P<D;BT7LBU7H(<*+1>CWT"-%\`G0
MC00!B<(#5?2+1?B+`(T$`@69>8):B47@@T7X!,%-Z`*+1>")P<')&XM%Z(M5
MY"'"BT7D]]`C1>P)T(T$`8G"`U7PBT7XBP"-!`(%F7F"6HE%](-%^`3!3>0"
MBT7TB<'!R1N+1>2+5>`APHM%X/?0(T7H"="-!`&)P@-5[(M%^(L`C00"!9EY
M@EJ)1?"#1?@$P4W@`HM%\(G!P<D;BT7@BU7T(<*+1?3WT"-%Y`G0C00!B<(#
M5>B+1?B+`(T$`@69>8):B47L@T7X!,%-]`*+1>R)P<')&XM%](M5\"'"BT7P
M]]`C1>`)T(T$`8G"`U7DBT7XBP"-!`(%F7F"6HE%Z(-%^`3!3?`"BT7HB<'!
MR1N+1?"+5>PAPHM%[/?0(T7T"="-!`&)P@-5X(M%^(L`C00"!9EY@EJ)1>2#
M1?@$P4WL`HM%Y(G!P<D;BT7LBU7H(<*+1>CWT"-%\`G0C00!B<(#5?2+1?B+
M`(T$`@69>8):B47@@T7X!,%-Z`*+1>")P<')&XM%Z(M5Y"'"BT7D]]`C1>P)
MT(T$`8G"`U7PBT7XBP"-!`(%F7F"6HE%](-%^`3!3>0"BT7TB<'!R1N+1>2+
M5>`APHM%X/?0(T7H"="-!`&)P@-5[(M%^(L`C00"!9EY@EJ)1?"#1?@$P4W@
M`HM%\(G!P<D;BT7@BU7T(<*+1?3WT"-%Y`G0C00!B<(#5>B+1?B+`(T$`@69
M>8):B47L@T7X!,%-]`*+1>R)P<')&XM%](M5\"'"BT7P]]`C1>`)T(T$`8G"
M`U7DBT7XBP"-!`(%F7F"6HE%Z(-%^`3!3?`"BT7HB<'!R1N+1?"+5>PAPHM%
M[/?0(T7T"="-!`&)P@-5X(M%^(L`C00"!9EY@EJ)1>2#1?@$P4WL`HM%Y(G!
MP<D;BT7LBU7H(<*+1>CWT"-%\`G0C00!B<(#5?2+1?B+`(T$`@69>8):B47@
M@T7X!,%-Z`*+1>")P<')&XM%Z(M5Y"'"BT7D]]`C1>P)T(T$`8G"`U7PBT7X
MBP"-!`(%F7F"6HE%](-%^`3!3>0"BT7TB<'!R1N+1>2+5>`APHM%X/?0(T7H
M"="-!`&)P@-5[(M%^(L`C00"!9EY@EJ)1?"#1?@$P4W@`HM%\(G!P<D;BT7@
MBU7T(<*+1?3WT"-%Y`G0C00!B<(#5>B+1?B+`(T$`@69>8):B47L@T7X!,%-
M]`*+1>R)P<')&XM%](M5\"'"BT7P]]`C1>`)T(T$`8G"`U7DBT7XBP"-!`(%
MF7F"6HE%Z(-%^`3!3?`"BT7HB<'!R1N+1?"+5>PAPHM%[/?0(T7T"="-!`&)
MP@-5X(M%^(L`C00"!9EY@EJ)1>2#1?@$P4WL`HM%Y(G!P<D;BT7LBU7H(<*+
M1>CWT"-%\`G0C00!B<(#5?2+1?B+`(T$`@69>8):B47@@T7X!,%-Z`*+1>")
MP<')&XM%Z(M5Y"'"BT7D]]`C1>P)T(T$`8G"`U7PBT7XBP"-!`(%F7F"6HE%
M](-%^`3!3>0"BT7TB<'!R1N+1>2+5>`QT#-%Z(T$`8G"`U7LBT7XBP"-!`(%
MH>O9;HE%\(-%^`3!3>`"BT7PB<'!R1N+1>"+5?0QT#-%Y(T$`8G"`U7HBT7X
MBP"-!`(%H>O9;HE%[(-%^`3!3?0"BT7LB<'!R1N+1?2+5?`QT#-%X(T$`8G"
M`U7DBT7XBP"-!`(%H>O9;HE%Z(-%^`3!3?`"BT7HB<'!R1N+1?"+5>PQT#-%
M](T$`8G"`U7@BT7XBP"-!`(%H>O9;HE%Y(-%^`3!3>P"BT7DB<'!R1N+1>R+
M5>@QT#-%\(T$`8G"`U7TBT7XBP"-!`(%H>O9;HE%X(-%^`3!3>@"BT7@B<'!
MR1N+1>B+5>0QT#-%[(T$`8G"`U7PBT7XBP"-!`(%H>O9;HE%](-%^`3!3>0"
MBT7TB<'!R1N+1>2+5>`QT#-%Z(T$`8G"`U7LBT7XBP"-!`(%H>O9;HE%\(-%
M^`3!3>`"BT7PB<'!R1N+1>"+5?0QT#-%Y(T$`8G"`U7HBT7XBP"-!`(%H>O9
M;HE%[(-%^`3!3?0"BT7LB<'!R1N+1?2+5?`QT#-%X(T$`8G"`U7DBT7XBP"-
M!`(%H>O9;HE%Z(-%^`3!3?`"BT7HB<'!R1N+1?"+5>PQT#-%](T$`8G"`U7@
MBT7XBP"-!`(%H>O9;HE%Y(-%^`3!3>P"BT7DB<'!R1N+1>R+5>@QT#-%\(T$
M`8G"`U7TBT7XBP"-!`(%H>O9;HE%X(-%^`3!3>@"BT7@B<'!R1N+1>B+5>0Q
MT#-%[(T$`8G"`U7PBT7XBP"-!`(%H>O9;HE%](-%^`3!3>0"BT7TB<'!R1N+
M1>2+5>`QT#-%Z(T$`8G"`U7LBT7XBP"-!`(%H>O9;HE%\(-%^`3!3>`"BT7P
MB<'!R1N+1>"+5?0QT#-%Y(T$`8G"`U7HBT7XBP"-!`(%H>O9;HE%[(-%^`3!
M3?0"BT7LB<'!R1N+1?2+5?`QT#-%X(T$`8G"`U7DBT7XBP"-!`(%H>O9;HE%
MZ(-%^`3!3?`"BT7HB<'!R1N+1?"+5>PQT#-%](T$`8G"`U7@BT7XBP"-!`(%
MH>O9;HE%Y(-%^`3!3>P"BT7DB<'!R1N+1>R+5>@QT#-%\(T$`8G"`U7TBT7X
MBP"-!`(%H>O9;HE%X(-%^`3!3>@"BT7@B<'!R1N+1>B+5>0QT#-%[(T$`8G"
M`U7PBT7XBP"-!`(%H>O9;HE%](-%^`3!3>0"BT7TB<'!R1N+1>2+5>`QT#-%
MZ(T$`8G"`U7LBT7XBP"-!`(%H>O9;HE%\(-%^`3!3>`"BT7PB<'!R1N+1>"+
M5?0QT#-%Y(T$`8G"`U7HBT7XBP"-!`(%H>O9;HE%[(-%^`3!3?0"BT7LB</!
MRQN+1>"+5?0)T"-%\(M5X(M-]"'*"="-!`.)P@-5Y(M%^(L`C00"+21#Y'")
M1>B#1?@$P4WP`HM%Z(G#P<L;BT7TBU7P"=`C1>R+5?2+3?`AR@G0C00#B<(#
M5>"+1?B+`(T$`BTD0^1PB47D@T7X!,%-[`*+1>2)P\'+&XM%\(M5[`G0(T7H
MBU7PBTWL(<H)T(T$`XG"`U7TBT7XBP"-!`(M)$/D<(E%X(-%^`3!3>@"BT7@
MB</!RQN+1>R+5>@)T"-%Y(M5[(M-Z"'*"="-!`.)P@-5\(M%^(L`C00"+21#
MY'")1?2#1?@$P4WD`HM%](G#P<L;BT7HBU7D"=`C1>"+5>B+3>0AR@G0C00#
MB<(#5>R+1?B+`(T$`BTD0^1PB47P@T7X!,%-X`*+1?")P\'+&XM%Y(M5X`G0
M(T7TBU7DBTW@(<H)T(T$`XG"`U7HBT7XBP"-!`(M)$/D<(E%[(-%^`3!3?0"
MBT7LB</!RQN+1>"+5?0)T"-%\(M5X(M-]"'*"="-!`.)P@-5Y(M%^(L`C00"
M+21#Y'")1>B#1?@$P4WP`HM%Z(G#P<L;BT7TBU7P"=`C1>R+5?2+3?`AR@G0
MC00#B<(#5>"+1?B+`(T$`BTD0^1PB47D@T7X!,%-[`*+1>2)P\'+&XM%\(M5
M[`G0(T7HBU7PBTWL(<H)T(T$`XG"`U7TBT7XBP"-!`(M)$/D<(E%X(-%^`3!
M3>@"BT7@B</!RQN+1>R+5>@)T"-%Y(M5[(M-Z"'*"="-!`.)P@-5\(M%^(L`
MC00"+21#Y'")1?2#1?@$P4WD`HM%](G#P<L;BT7HBU7D"=`C1>"+5>B+3>0A
MR@G0C00#B<(#5>R+1?B+`(T$`BTD0^1PB47P@T7X!,%-X`*+1?")P\'+&XM%
MY(M5X`G0(T7TBU7DBTW@(<H)T(T$`XG"`U7HBT7XBP"-!`(M)$/D<(E%[(-%
M^`3!3?0"BT7LB</!RQN+1>"+5?0)T"-%\(M5X(M-]"'*"="-!`.)P@-5Y(M%
M^(L`C00"+21#Y'")1>B#1?@$P4WP`HM%Z(G#P<L;BT7TBU7P"=`C1>R+5?2+
M3?`AR@G0C00#B<(#5>"+1?B+`(T$`BTD0^1PB47D@T7X!,%-[`*+1>2)P\'+
M&XM%\(M5[`G0(T7HBU7PBTWL(<H)T(T$`XG"`U7TBT7XBP"-!`(M)$/D<(E%
MX(-%^`3!3>@"BT7@B</!RQN+1>R+5>@)T"-%Y(M5[(M-Z"'*"="-!`.)P@-5
M\(M%^(L`C00"+21#Y'")1?2#1?@$P4WD`HM%](G#P<L;BT7HBU7D"=`C1>"+
M5>B+3>0AR@G0C00#B<(#5>R+1?B+`(T$`BTD0^1PB47P@T7X!,%-X`*+1?")
MP\'+&XM%Y(M5X`G0(T7TBU7DBTW@(<H)T(T$`XG"`U7HBT7XBP"-!`(M)$/D
M<(E%[(-%^`3!3?0"BT7LB</!RQN+1>"+5?0)T"-%\(M5X(M-]"'*"="-!`.)
MP@-5Y(M%^(L`C00"+21#Y'")1>B#1?@$P4WP`HM%Z(G#P<L;BT7TBU7P"=`C
M1>R+5?2+3?`AR@G0C00#B<(#5>"+1?B+`(T$`BTD0^1PB47D@T7X!,%-[`*+
M1>2)P<')&XM%[(M5Z#'0,T7PC00!B<(#5?2+1?B+`(T$`BTJ/ITUB47@@T7X
M!,%-Z`*+1>")P<')&XM%Z(M5Y#'0,T7LC00!B<(#5?"+1?B+`(T$`BTJ/ITU
MB47T@T7X!,%-Y`*+1?2)P<')&XM%Y(M5X#'0,T7HC00!B<(#5>R+1?B+`(T$
M`BTJ/ITUB47P@T7X!,%-X`*+1?")P<')&XM%X(M5]#'0,T7DC00!B<(#5>B+
M1?B+`(T$`BTJ/ITUB47L@T7X!,%-]`*+1>R)P<')&XM%](M5\#'0,T7@C00!
MB<(#5>2+1?B+`(T$`BTJ/ITUB47H@T7X!,%-\`*+1>B)P<')&XM%\(M5[#'0
M,T7TC00!B<(#5>"+1?B+`(T$`BTJ/ITUB47D@T7X!,%-[`*+1>2)P<')&XM%
M[(M5Z#'0,T7PC00!B<(#5?2+1?B+`(T$`BTJ/ITUB47@@T7X!,%-Z`*+1>")
MP<')&XM%Z(M5Y#'0,T7LC00!B<(#5?"+1?B+`(T$`BTJ/ITUB47T@T7X!,%-
MY`*+1?2)P<')&XM%Y(M5X#'0,T7HC00!B<(#5>R+1?B+`(T$`BTJ/ITUB47P
M@T7X!,%-X`*+1?")P<')&XM%X(M5]#'0,T7DC00!B<(#5>B+1?B+`(T$`BTJ
M/ITUB47L@T7X!,%-]`*+1>R)P<')&XM%](M5\#'0,T7@C00!B<(#5>2+1?B+
M`(T$`BTJ/ITUB47H@T7X!,%-\`*+1>B)P<')&XM%\(M5[#'0,T7TC00!B<(#
M5>"+1?B+`(T$`BTJ/ITUB47D@T7X!,%-[`*+1>2)P<')&XM%[(M5Z#'0,T7P
MC00!B<(#5?2+1?B+`(T$`BTJ/ITUB47@@T7X!,%-Z`*+1>")P<')&XM%Z(M5
MY#'0,T7LC00!B<(#5?"+1?B+`(T$`BTJ/ITUB47T@T7X!,%-Y`*+1?2)P<')
M&XM%Y(M5X#'0,T7HC00!B<(#5>R+1?B+`(T$`BTJ/ITUB47P@T7X!,%-X`*+
M1?")P<')&XM%X(M5]#'0,T7DC00!B<(#5>B+1?B+`(T$`BTJ/ITUB47L@T7X
M!,%-]`*+1>R)P<')&XM%](M5\#'0,T7@C00!B<(#5>2+1?B+`(T$`BTJ/ITU
MB47H@T7X!,%-\`*+1>B)P<')&XM%\(M5[#'0,T7TC00!B<(#5>"+1?B+`(T$
M`BTJ/ITUB47D@T7X!,%-[`*+1>2)P<')&XM%[(M5Z#'0,T7PC00!B<(#5?2+
M1?B+`(T$`BTJ/ITUB47@@T7X!,%-Z`*+1>")P<')&XM%Z(M5Y#'0,T7LC00!
MB<(#5?"+1?B+`(T$`BTJ/ITUB47T@T7X!,%-Y`*+10B+`(G"`U7TBT4(B1"+
M10B+0`2)P@-5X(M%"(E0!(M%"(M`"(G"`U7DBT4(B5`(BT4(BT`,B<(#5>B+
M10B)4`R+10B+0!")P@-5[(M%"(E0$('$<`$``%M=PU6)Y8M%",<``2-%9XM%
M",=`!(FKS>^+10C'0`C^W+J8BT4(QT`,=E0R$(M%",=`$/#ATL.+10C'0!0`
M````BT4(QT`8`````(M%",=`7`````!=PU6)Y8/L*(M%"(M`%(M5$,'B`P'0
MB47TBT4(BT`4.T7T=@^+10B+0!B-4`&+10B)4!B+10B+5?2)4!2+10B+0!B+
M51#!ZAV-%!"+10B)4!B+10B+0%R%P`^$K````(M%"(M`7+I`````B=$IP8G(
MB47PBT7P.T40?@:+11")1?"+1?"+50B-2AR+50B+4ER-%!&)1"0(BT4,B40D
M!(D4).A_WO__BT7P*440BT7P`44,BT4(BT!<B<(#5?"+10B)4%R+10B+0%R#
M^$!U:HM%"(D$).@J[/__ZS"+10B-4!S'1"0(0````(M%#(E$)`2)%"3H+=[_
M_X-%#$"#;1!`BT4(B00DZ/CK__^#?1`_?\J+11"+50B#PAR)1"0(BT4,B40D
M!(D4).CXW?__BT4(BU40B5!<ZP&0R<-5B>6#[`2+10R)!"3HM^O__XM%#(L`
MP>@8B<*+10B($(M%"(U0`8M%#(L`P>@0B`*+10B-4`*+10R+`,'H"(@"BT4(
MC5`#BT4,BP"(`HM%"(U0!(M%#(M`!,'H&(@"BT4(C5`%BT4,BT`$P>@0B`*+
M10B-4`:+10R+0`3!Z`B(`HM%"(U0!XM%#(M`!(@"BT4(C5`(BT4,BT`(P>@8
MB`*+10B-4`F+10R+0`C!Z!"(`HM%"(U0"HM%#(M`",'H"(@"BT4(C5`+BT4,
MBT`(B`*+10B-4`R+10R+0`S!Z!B(`HM%"(U0#8M%#(M`#,'H$(@"BT4(C5`.
MBT4,BT`,P>@(B`*+10B-4`^+10R+0`R(`HM%"(U0$(M%#(M`$,'H&(@"BT4(
MC5`1BT4,BT`0P>@0B`*+10B-4!*+10R+0!#!Z`B(`HM%"(U0$XM%#(M`$(@"
MR<-5B>6#["B+10R+0!2)1?"+10R+0!B)1?2+1?#!Z`.#X#^)1>R+10R-4!R+
M1>R-!`+&`("#1>P!@WWL.'Y3N$`````K1>R+50R-2AR+5>R-%!&)1"0(QT0D
M!`````")%"3H\MK__XM%#(D$).@%ZO__BT4,@\`<QT0D"#@```#'1"0$````
M`(D$).C)VO__ZRBX.````"M%[(M5#(U*'(M5[(T4$8E$)`C'1"0$`````(D4
M).B?VO__BT7TP>@8B<*+10R(4%2+1?3!Z!")PHM%#(A058M%],'H"(G"BT4,
MB%!6BT7TB<*+10R(4%>+1?#!Z!B)PHM%#(A06(M%\,'H$(G"BT4,B%!9BT7P
MP>@(B<*+10R(4%J+1?")PHM%#(A06XM%#(E$)`2+10B)!"3H>?W__\G#58GE
M@^PHQT7P`````,=%]`````#HJ-O__XD$).B`V___B47T@WWT`'0(BT7TBP")
M1?"+1?#)PU6)Y8/L&,<$)`````#H"-W__XL`B00DZ/[9__^)!"3H%MS__XE$
M)`2+10B)!"3H[QX``(7`=7C'!"0`````Z-?<__^+`(D$).C-V?__B00DZ.7;
M__^+0!`E`/```#T`0```="W'!"0`````Z*K<__^+`(D$).B@V?__B00DZ+C;
M__^+0!`E`/```#T`H```=1['1"0$`@```(M%"(D$).CFV?__A<!U![@!````
MZP6X`````,G#58GE4X/L5,=%Z`````#'1>P`````QT70IMP$",=%U+;<!`C'
M1=B^W`0(QT7<R]P$",=%X-#<!`C'1>3BW`0(QT7T`````,=%\`````#IQ0``
M`(M%Z(D$).@1W___B47L@WWL`'0*BT7L#[8`A,!U%XM%"(E$)`2+1>B)!"3H
M!M___^F,````BT4(B40D!(M%[(D$).B+VO__A<!U=HM%"(D$).CLV?__B<.A
MA$T%"(D$).C=V?__`<.+1>R)!"3HT-G__XT$`X/``HD$).ABVO__B47TBQ6$
M304(N-';!`B+3>R)3"00B50D#(M5"(E4)`B)1"0$BT7TB00DZ`/7__^+1?2)
M1"0$BT7HB00DZ'7>__^#1?`!BT7PBT2%T(E%Z(M%Z`^V`(3`#X4C____@\14
M6UW#58GE4X'L1($``,=%P`````#'1<0`````QT7(`````,=%J./<!`C'1:SK
MW`0(QT6PS]L$",=%M.+<!`C'19!)W`0(QT64\-P$",=%F/?<!`C'19S_W`0(
MQT6@!-T$",=%I.+<!`C'180(W00(QT6(#=T$",=%C.+<!`C'1<P6W00(QT70
MXMP$",=%U`````#'1=@`````QT7<`````,=%[`````#'!"2YVP0(Z(G=__^)
M1<B#?<@`="6+1<@/M@"$P'0;BT7(B00DZ/W]__^+1<B)!"3H1MK__^E!!0``
MZ/O\__^)1=B#?=@`=4G'1;@`````ZR:+1<2)!"3H.=W__XE%R(-]R`!T#HM%
MR(D$).@+VO__B478@T6X`8-]V`!U%(M%N(M$A82)1<2+1<0/M@"$P'7`@WW8
M`'4)QT78&]T$".L^BT78B46\ZRSHCM?__XL0BT6\#[8`#[[``<"-!`(/MP`/
MM\"#X`B%P'4&BT6\Q@!?@T6\`8M%O`^V`(3`=<K'1;@`````ZS6+1<2)!"3H
MH]S__XE%R(-]R`!T'8M%R(D$).AK_/__A<!T#HM%R(D$).AFV?__B47`@T6X
M`8-]P`!U%(M%N(M$A9")1<2+1<0/M@"$P'6QQT6X`````.LABT7(B00DZ"?\
M__^%P'0.BT7(B00DZ"+9__^)1<"#1;@!@WW``'44BT6XBT2%J(E%R(M%R`^V
M`(3`=<6+1<")!"3H-M?__XG#BT7,B00DZ"G7__\!PXM%V(D$).@<U___`<.+
M1=")!"3H#]?__XT$`P4`!```B47LBT7LB00DZ)G7__^)1=R+%8!-!0BX(MT$
M"(M-V(E,)!2+3<R)3"00B50D#(M5P(E4)`B)1"0$BT7<B00DZ#/4___'1"0$
M[0$``(M%W(D$).A0U/__QP0DR]P$".A^V___B47(@WW(`'0ABT7(B00DZ%#8
M__^)PHM%"(L`B50D!(D$).BPWO__B474@WW4`'4(BT4(BP")1=3HU./__X7`
M#X4N`@``QT0D!`````"+1=2)!"3HS-?__XE%X(-]X``/A`X"``#'1"0,`@``
M`,=$)`3N____QT0D"/____^+1>")!"3H?-3__\=$)`@&````C87X?O__B40D
M!(M%X(D$).C?U/__#[:%^'[__X3`#X7#````#[:%^7[__SQ##X6T````#[:%
M^G[__SQ!#X6E````#[:%^W[__SQ##X66````#[:%_'[__SQ(#X6'````#[:%
M_7[__SQ%=7S'1"0,`@```,=$)`3&____QT0D"/____^+1>")!"3HYM/__\=$
M)`@I````C87X?O__B40D!(M%X(D$).A)U/__BQ6`304(N"O=!`B+3=")3"04
MC8WX?O__B4PD$(E4)`R+5=R)5"0(B40D!(M%W(D$).BCTO__D.G,`0``C87X
M_O__B00DZ(CU___K'XM%Y(E$)`B-A?A^__^)1"0$C87X_O__B00DZ+OU___'
M1"0(`(```(V%^'[__XE$)`2+1>")!"3HP=/__XE%Y(-]Y`!_NXM%X(D$).@]
MU?__C87X_O__B40D!(V%Y'[__XD$).C^]___QT7H`````.LVBT7H#[:$!>1^
M__\/MLBZ.MT$"(M%Z`'`B<.-A5O___\!V(E,)`B)5"0$B00DZ.K1__^#1>@!
M@WWH$W[$QD6#`(L5@$T%"+@KW00(BTW0B4PD%(V-6____XE,)!")5"0,BU7<
MB50D"(E$)`2+1=R)!"3HIM'__^G0````QT7P`````(M%W(D$).@?U/__B47T
MQT0D!(#<!`C'!"3TVP0(Z/S8___HD]'__XL-@$T%"+H_W00(BUW0B5PD%(E$
M)!")3"0,BT7<B40D"(E4)`2+1=R)!"3H0]'__^M,BT7TBU7<C00"Q@``@T7P
M`>A,T?__BPV`304(NDW=!`B+7=")7"08BUWPB5PD%(E$)!")3"0,BT7<B40D
M"(E4)`2+1=R)!"3H]=#__\=$)`3M`0``BT7<B00DZ!+1__^#^/]U#.C(T/__
MBP"#^!%TD(M%W(E$)`3'!"2YVP0(Z$+8__^+1=R)!"3HK_C__XM%W('$1($`
M`%M=PU6)Y5.![(0```#'1?``````@WT(``^$00$``(M%"`^V`(3`#X0V`0``
MBT4(B00DZ&/2__^)1>B#?>@`#X7J````Z1H!``"+1>R#P!/'1"0$S]L$"(D$
M).C+U/__A<`/A,@```"+1>R#P!/'1"0$7MT$"(D$).BMU/__A<`/A*H```"+
M10B)!"3HJM+__XG#BT7L@\`3B00DZ)K2__^-!`.#P`*)1?2+1?2)!"3H)M/_
M_XE%\(M%[(U0$[AAW00(B50D#(M5"(E4)`B)1"0$BT7PB00DZ,[/__^+1?"-
M58B)5"0$B00DZ.05``"#^/]T'(M%F"4`\```/0!```!U#8M%\(D$).CV_O__
MZPN+1?")!"3H,-+__XM%\(D$).@ET?__QT7P`````.L!D(M%Z(D$).C0T?__
MB47L@WWL``^%`O___XM%Z(D$).A(TO__BT4(B00DZ)W2___K!)#K`9"!Q(0`
M``!;7<-5B>6#["B+10B)!"3H6]S__XE%\(M%\(D$).@+W/__B47TZ!3?__^%
MP'0S@WT(`'0MBT4(#[8`A,!T(\=$)`06W00(BT7TB00DZ!#2__\[1?1U"XM%
M"(D$).@Y_O__R<-5B>53@^P4QP0D`````.@KT___BP")!"3H(=#__XD$).C)
MSO__BP"+6`3'!"0`````Z`C3__^+`(D$).C^S___B00DZ$;/__\/M@"(0QC'
M!"0`````Z.32__^+`(D$).C:S___B00DZ(+.__^+`(M8!,<$)`````#HP=+_
M_XL`B00DZ+?/__^)!"3H#\___XL`#[=`$&8E_P%FB4,:QP0D`````.B5TO__
MBP")!"3HB\___XD$).@SSO__BP"+6`3'!"0`````Z'+2__^+`(D$).AHS___
MQT0D"`````#'1"0$XMP$"(D$).C0T?__B4,<QP0D`````.A!TO__BP")!"3H
M-\___XD$).C?S?__BP"+6`3'!"0`````Z![2__^+`(D$).@4S___B00DZ#S.
M__^+`(E#(,<$)`````#H^]'__XL`B00DZ/'.__^)!"3HF<W__XL`BU@$QP0D
M`````.C8T?__BP")!"3HSL[__XD$).C6T/__BP"%P'0EQP0D`````.BTT?__
MBP")!"3HJL[__XD$).BRT/__BP"+0&SK!;@`````B4,DQP0D`````.B'T?__
MBP")!"3H?<[__XD$).@ES?__BP"+0`3'0"@`````QP0D`````.A=T?__BP")
M!"3H4\[__XD$).C[S/__BP"+0`3'0"P`````QP0D`````.@ST?__BP")!"3H
M*<[__XD$).C1S/__BP"+6`3'!"0`````Z!#1__^+`(D$).@&SO__B00DZ+[0
M__^+`(E#,(/$%%M=PU6)Y8/L&,<$)`````#HX=#__XL`B00DZ-?-___'1"0$
M_____XD$).@7SO__QP0D`````.B[T/__BP")!"3HL<W__\=$)`@`````QT0D
M!'K%!`B)!"3HZ=#__\G#58GE5E.#['#'1;``````QP0D`````.A\T/__BP")
M!"3H<LW__XD$).CJS?__Q@`!QP0DV-L$".AET___B46T@WVT`'07BT6T#[8`
M/#%U#8M%M(/``0^V`(3`=`7H'MK__\<$)`````#H*M#__XL`B00DZ"#-___'
M1"0,"P```,=$)`@!````QT0D!&?=!`B)!"3HP,S__XE%G(-]G``/A*8"``"+
M19R)1;B+1;B+0`@E_P```(/X"70LBT6XBT`()?\```"#^`IT',=$)`@>````
MQT0D!&S=!`C'!"34W00(Z`'/__^+1;B+0`@E`,```#T`@```=2"+1;B+0`@E
M_P```(/X"70LBT6XBT`()?\```"#^`IT',=$)`@>````QT0D!`C>!`C'!"34
MW00(Z+/.__^+1;B#P`R+`(M`&(E%H,=%K`$```#IG`$``(M%K(U8_\<$)```
M``#H-\___XL`B00DZ"W,___'1"0,`````(E<)`B+5:")5"0$B00DZ)+-__^)
M1:2#?:0`#X1H`0``BT6DBP"+0`@E``0``(7`#X3D````BT6DBP")1;R+1;R+
M0`@E_P```(/X!'<<QT0D""(```#'1"0$N-X$",<$)-3=!`CH#,[__XM%O(M`
M""7_````@_@+=1S'1"0((@```,=$)`3HW@0(QP0DU-T$".C@S?__BT6\BT`(
M)?\```"#^`QU',=$)`@B````QT0D!!C?!`C'!"34W00(Z+3-__^+1;R+0`@E
M`,```#T`@```=3R+1;R+0`@E_P```(/X"700BT6\BT`()?\```"#^`IU',=$
M)`@B````QT0D!$C?!`C'!"34W00(Z&;-__^+1;R#P`R+`.LWBT6DBQC'!"0`
M````Z/O-__^+`(D$).CQRO__QT0D#`(```#'1"0(`````(E<)`2)!"3H-<[_
M_XL5S$T%"(M-K,'A`@'*BQ*)1"0$B10DZ-G-__^%P'4;@T6P`8-%K`&AR$T%
M"#E%K`^,5O[__^L$D.L!D*'(304(@^@!.T6P=3_'1:P!````ZRS'!"0`````
MZ'?-__^+`(D$).AMRO__BU6@B50D!(D$).@.RO__B46H@T6L`:'(304(.46L
M?,K'!"0`````Z$'-__^+`(D$).@WRO__QT0D#`4```#'1"0(`0```,=$)`3P
MWP0(B00DZ-?)__^)19R#?9P`#X0J`@``BT6<B47`BT7`BT`()?\```"#^`ET
M+(M%P(M`""7_````@_@*=!S'1"0(,````,=$)`1LW00(QP0DU-T$".@8S/__
MBT7`BT`()0#````]`(```'4@BT7`BT`()?\```"#^`ET+(M%P(M`""7_````
M@_@*=!S'1"0(,````,=$)`0(W@0(QP0DU-T$".C*R___BT7`@\`,BP"+&,<$
M)`````#H9,S__XL`B00DZ%K)___'1"0(\M\$"(E<)`2)!"3H)LG__XM%G(E%
MQ(M%Q(M`""7_````@_@)="R+1<2+0`@E_P```(/X"G0<QT0D"#(```#'1"0$
M;-T$",<$)-3=!`CH5,O__XM%Q(M`""4`P```/0"```!U((M%Q(M`""7_````
M@_@)="R+1<2+0`@E_P```(/X"G0<QT0D"#(```#'1"0$"-X$",<$)-3=!`CH
M!LO__XM%Q(/`#(L`BP"+0`@E``!``(7`#X2\````BT6<B47(BT7(BT`()?\`
M``"#^`ET+(M%R(M`""7_````@_@*=!S'1"0(,@```,=$)`1LW00(QP0DU-T$
M".BJRO__BT7(BT`()0#````]`(```'4@BT7(BT`()?\```"#^`ET+(M%R(M`
M""7_````@_@*=!S'1"0(,@```,=$)`0(W@0(QP0DU-T$".A<RO__BT7(@\`,
MBP"+&,<$)`````#H]LK__XL`B00DZ.S'__^)7"0$B00DZ,#)___'!"0`````
MZ-3*__^+`(D$).C*Q___QT0D#`4```#'1"0(`0```,=$)`3WWP0(B00DZ&K'
M__^)19R#?9P`#X2O`0``QT7,`````,<$),+;!`CHE,W__XE%S(-]S``/A,@`
M``"+19R)1="+1="+0`@E_P```(/X"70LBT70BT`()?\```"#^`IT',=$)`@X
M````QT0D!&S=!`C'!"34W00(Z(O)__^+1="+0`@E`,```#T`@```=2"+1="+
M0`@E_P```(/X"70LBT70BT`()?\```"#^`IT',=$)`@X````QT0D!`C>!`C'
M!"34W00(Z#W)__^+1="#P`R+`(L8QP0D`````.C7R?__BP")!"3HS<;__XM5
MS(E4)`B)7"0$B00DZ)K&___IQP```*',304(BS"+19R)1=2+1=2+0`@E_P``
M`(/X"70LBT74BT`()?\```"#^`IT',=$)`@\````QT0D!&S=!`C'!"34W00(
MZ+S(__^+1=2+0`@E`,```#T`@```=2"+1=2+0`@E_P```(/X"70LBT74BT`(
M)?\```"#^`IT',=$)`@\````QT0D!`C>!`C'!"34W00(Z&[(__^+1=2#P`R+
M`(L8QP0D`````.@(R?__BP")!"3H_L7__XET)`B)7"0$B00DZ%[*___'!"0`
M````Z.+(__^+`(D$).C8Q?__B00DZ%#&___&``#'!"0`````Z,'(__^+`(D$
M).BWQ?__B00DZ-_(___'``````#'!"2YVP0(Z*?+__^CQ$T%"*'$304(A<`/
MA2X&``"AS$T%"(D$).A/[?__H\1-!0B+'<Q-!0B+19R)1=B+1=B+0`@E_P``
M`(/X"70LBT78BT`()?\```"#^`IT',=$)`AL````QT0D!&S=!`C'!"34W00(
MZ(''__^+1=B+0`@E`,```#T`@```=2"+1=B+0`@E_P```(/X"70LBT78BT`(
M)?\```"#^`IT',=$)`AL````QT0D!`C>!`C'!"34W00(Z#/'__^+1=B#P`R+
M`(L`BT`()0`$``"%P`^$?`$``(M%G(E%X(M%X(M`""7_````@_@)="R+1>"+
M0`@E_P```(/X"G0<QT0D"&P```#'1"0$;-T$",<$)-3=!`CHU\;__XM%X(M`
M""4`P```/0"```!U((M%X(M`""7_````@_@)="R+1>"+0`@E_P```(/X"G0<
MQT0D"&P```#'1"0$"-X$",<$)-3=!`CHB<;__XM%X(/`#(L`BP")1=R+1=R+
M0`@E_P```(/X!'<<QT0D"&P```#'1"0$N-X$",<$)-3=!`CH4,;__XM%W(M`
M""7_````@_@+=1S'1"0(;````,=$)`3HW@0(QP0DU-T$".@DQO__BT7<BT`(
M)?\```"#^`QU',=$)`AL````QT0D!!C?!`C'!"34W00(Z/C%__^+1=R+0`@E
M`,```#T`@```=3R+1=R+0`@E_P```(/X"700BT7<BT`()?\```"#^`IU',=$
M)`AL````QT0D!$C?!`C'!"34W00(Z*K%__^+1=R#P`R+`.G,````BT6<B47D
MBT7DBT`()?\```"#^`ET+(M%Y(M`""7_````@_@*=!S'1"0(;````,=$)`1L
MW00(QP0DU-T$".A;Q?__BT7DBT`()0#````]`(```'4@BT7DBT`()?\```"#
M^`ET+(M%Y(M`""7_````@_@*=!S'1"0(;````,=$)`0(W@0(QP0DU-T$".@-
MQ?__BT7D@\`,BP"+,,<$)`````#HI\7__XL`B00DZ)W"___'1"0,`@```,=$
M)`@`````B70D!(D$).CAQ?__B5PD!(D$).B5P___B46LBT6<B47HBT7HBT`(
M)?\```"#^`ET+(M%Z(M`""7_````@_@*=!S'1"0(;@```,=$)`1LW00(QP0D
MU-T$".B`Q/__BT7HBT`()0#````]`(```'4@BT7HBT`()?\```"#^`ET+(M%
MZ(M`""7_````@_@*=!S'1"0(;@```,=$)`0(W@0(QP0DU-T$".@RQ/__BT7H
M@\`,BP"+`(M`""4`!```A<`/A'P!``"+19R)1?"+1?"+0`@E_P```(/X"70L
MBT7PBT`()?\```"#^`IT',=$)`AN````QT0D!&S=!`C'!"34W00(Z-;#__^+
M1?"+0`@E`,```#T`@```=2"+1?"+0`@E_P```(/X"70LBT7PBT`()?\```"#
M^`IT',=$)`AN````QT0D!`C>!`C'!"34W00(Z(C#__^+1?"#P`R+`(L`B47L
MBT7LBT`()?\```"#^`1W',=$)`AN````QT0D!+C>!`C'!"34W00(Z$_#__^+
M1>R+0`@E_P```(/X"W4<QT0D"&X```#'1"0$Z-X$",<$)-3=!`CH(\/__XM%
M[(M`""7_````@_@,=1S'1"0(;@```,=$)`08WP0(QP0DU-T$".CWPO__BT7L
MBT`()0#````]`(```'4\BT7LBT`()?\```"#^`ET$(M%[(M`""7_````@_@*
M=1S'1"0(;@```,=$)`1(WP0(QP0DU-T$".BIPO__BT7L@\`,BP#IS````(M%
MG(E%](M%](M`""7_````@_@)="R+1?2+0`@E_P```(/X"G0<QT0D"&X```#'
M1"0$;-T$",<$)-3=!`CH6L+__XM%](M`""4`P```/0"```!U((M%](M`""7_
M````@_@)="R+1?2+0`@E_P```(/X"G0<QT0D"&X```#'1"0$"-X$",<$)-3=
M!`CH#,+__XM%](/`#(L`BQC'!"0`````Z*;"__^+`(D$).B<O___QT0D#`(`
M``#'1"0(`````(E<)`2)!"3HX,+__XL5S$T%"(L2BTVLB4PD#(E$)`B)5"0$
MQP0D_-\$".BMP?__H<1-!0C'1"0$[0$``(D$).@8OO__B46L@WVL`'0T@WVL
M$70N@WVL_W0HBQ7$304(H<Q-!0B+`(M-K(E,)`R)5"0(B40D!,<$)"S@!`CH
M6\'__X/$<%M>7<-5B>6#["C'!"0`````Z/+!__^+`(D$).CHOO__B00DZ`S#
M___'!"0`````Z-3!__^+`(D$).C*OO__QT0D%`````#'1"00XMP$",=$)`SB
MW`0(QT0D""'(!`C'1"0$>N`$"(D$).AZO___R<-5B>6#Y/"#[$"-11")1"0(
MC44,B40D!(U%"(D$).A6P?__QT0D"+B4!`C'1"0$N)0$",<$)(B6!`CH<@(`
M`,<$)`````#H?K[__P^V`(3`=4WH8K[__Z/`304(H<!-!0B%P'4,QP0D`0``
M`.AHP?__H<!-!0B)!"3H"[___\<$)`````#H#\'__XL`B00DZ`6^__^)!"3H
M7<#__\8``,<$)`````#H[L#__XL`B00DZ.2]__^)!"3H[,#__P^V$(/*`H@0
MQP0D`````.C(P/__BP")!"3HOKW__XD$).C&P/__#[80@\H!B!"+10B#P`6Z
M`````(E$)"B)5"0LWVPD*-GNWL'=!9C@!`C9R=KIW^">#Y?`A,!T#,<$)*1-
M!0CHP[___XM%"(/`!<'@`HD$).C2O___H\Q-!0BAS$T%"(M5#(L2B1"AS$T%
M"(/`!,<`C^`$"*',304(@\`(QP#`X`0(QP7(304(`P```*',304(BQ7(304(
MP>("`=#'`)+@!`BAR$T%"(/``:/(304(QT0D/`$```#K+(L5S$T%"*'(304(
M`T0D/(/H`<'@`@'"BT4,BTPD/,'A`@'(BP")`H-$)#P!BT4(.40D/'S+H<Q-
M!0B+30B+%<A-!0B-%!&#Z@'!X@(!T,<``````(L5S$T%"(M-"*'(304(C00!
MC4C_H<!-!0C'1"00`````(E4)`R)3"0(QT0D!+36!`B)!"3H8;O__XE$)#B#
M?"0X`'41H<!-!0B)!"3H^;O__XE$)#BAP$T%"(D$).CXO?__QP0DZ-L$".A&
MPO__A<!U,*'$304(A<!U$<<$)+G;!`CH+<+__Z/$304(H<1-!0B%P'0-H<1-
M!0B)!"3H:NO__Z'`304(B00DZ-NZ___HEKS__XM$)#C)PY"0D)"0D)"058GE
M4^@R````@<-?<@``@^P0BX,PC___B40D#(M%$(E$)`B+10R)1"0$BT4(B00D
MZ#.[__^#Q!!;7<.+'"3#D%6)Y5W#C70F`(V\)P````!5B>575E/HX/___X'#
M#7(``(/L'.C/N?__C;O8_O__C8/8_O__*<?!_P*%_W0D,?:+11")1"0(BT4,
MB40D!(M%"(D$)/^4L]C^__^#Q@$Y_G+>@\0<6UY?7<.0D)"0D)!5B>53@^P,
MBT4,Z'S___^!PZEQ``#'!"0#````B40D"(M%"(E$)`3H3+K__X/$#%M=PY"0
MD)"0D)"0D)"0D)"058GE4X/L#(M%#.@\____@<-I<0``QP0D`P```(E$)`B+
M10B)1"0$Z"R[__^#Q`Q;7<.0D)"0D)"0D)"0D)"0D%6)Y5.#[`2A$$L%"(/X
M_W03NQ!+!0AFD(/K!/_0BP.#^/]U](/$!%M=PY"058GE4X/L!.@`````6X'#
M`'$``.@<OO__65O)PP````````````````````````````````,````!``(`
M``````````!P97)L>'-I+F,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R
M`"]P<F]C+W-E;&8O97AE`"\`.@`O<')O8R\E:2\E<P!E>&4`4$%27U1%35``
M4$%27U!23T=.04U%`"X`)7,E<R5S`%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?05)'0P!0
M05)?05)'5E\P`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`
M4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!0
M05)?0TQ%04X]`#$```!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M(```3$1?3$E"4D%265]0051(`$Q)0E!!5$@`3$E"4D%265]0051(`%!!5$@`
M1%E,1%],24)205)97U!!5$@``$,Z7%1%35``+W1M<`!435!$25(`5$5-4$1)
M4@!414U0`%1-4`!54T52`%5315).04U%`'!A<BT`4UE35$5-`"5S)7,E<R5S
M`"5S)7-C86-H92TE<R5S`"4P,G@`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE
M=2TE=25S`"XN`"5S+R5S`$%21U8`*"AS=G1Y<&4I*"AS:'!L97`I+3YS=E]F
M;&%G<R`F(#!X9F8I*2`]/2!35G1?4%9'5B!\?"`H*'-V='EP92DH*'-H<&QE
M<"DM/G-V7V9L86=S("8@,'AF9BDI(#T](%-6=%]05DQ6``!!<W-E<G1I;VX@
M)7,@9F%I;&5D.B!F:6QE(")I;G1E<FYA;',N8R(L(&QI;F4@)60`````*"@H
M*'-H<&QE<"DM/G-V7V9L86=S("8@*#!X,#`P,#0P,#!\,'@P,#`P.#`P,"DI
M(#T](#!X,#`P,#@P,#`I("8F("@H*'-V='EP92DH*'-H<&QE<"DM/G-V7V9L
M86=S("8@,'AF9BDI(#T](%-6=%]05D=6('Q\("@H<W9T>7!E*2@H<VAP;&5P
M*2T^<W9?9FQA9W,@)B`P>&9F*2D@/3T@4U9T7U!63%8I*0`````H*'-V='EP
M92DH*%]S=FDI+3YS=E]F;&%G<R`F(#!X9F8I*2`^/2!35G1?4%8````H*'-V
M='EP92DH*%]S=FDI+3YS=E]F;&%G<R`F(#!X9F8I*2`A/2!35G1?4%9!5@`H
M*'-V='EP92DH*%]S=FDI+3YS=E]F;&%G<R`F(#!X9F8I*2`A/2!35G1?4%9(
M5@`A*"@H*%]S=FDI+3YS=E]F;&%G<R`F("@P>#`P,#`T,#`P?#!X,#`P,#@P
M,#`I*2`]/2`P>#`P,#`X,#`P*2`F)B`H*"AS=G1Y<&4I*"A?<W9I*2T^<W9?
M9FQA9W,@)B`P>&9F*2D@/3T@4U9T7U!61U8@?'P@*"AS=G1Y<&4I*"A?<W9I
M*2T^<W9?9FQA9W,@)B`P>&9F*2D@/3T@4U9T7U!63%8I*0`8`'!E<FP`,```
M```E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@
M)6DN"@`E<SH@8W)E871I;VX@;V8@<')I=F%T92!T96UP;W)A<GD@<W5B9&ER
M96-T;W)Y("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN"@!);G1E<FYA
M;',Z.E!!4CHZ0D]/5``M90`M+0```````(#____/07!A<BYP;```````````
M````````````````````````(R$O=7-R+V)I;B]P97)L"@IE=F%L("=E>&5C
M("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[(",@
M;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P
M;#L*"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE
M<R!A="!C;VUP:6QE('1I;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U
M.0H*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![
M(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@(')E<75I<F4@1FEL93HZ5&5M
M<#L*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!R97%U:7)E($9I
M;&4Z.E-P96,["B`@("!M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I
M<FYA;64H)'!A<E]T96UP*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@
M:6X@(B1P87)?=&5M<")]*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS
M=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PH@
M("`@<FUD:7(@)'!A<E]T96UP.PH@("`@(R!$;VXG="!R96UO=F4@=&]P9&ER
M(&)E8V%U<V4@=&AI<R!C875S97,@82!R86-E('=I=&@@;W1H97(@87!P<PH@
M("`@(R!T:&%T(&%R92!T<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD("1P
M87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["B`@("`@("`@(R!3;VUE
M=&AI;F<@=V5N="!W<F]N9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D:7)E
M8W1O<GDN("!4:&ES"B`@("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O;B!P
M;&%T9F]R;7,@=&AA="!D:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@("`@
M("`@(R!L:6)R87)I97,@86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S
M92X@56YL:6YK('=I=&@@82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L;"!C
M;VUM86YD('-O('1H92!F:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B>2!T
M:&ES('!R;V-E<W,N"B`@("`@("`@(R!$;VXG="!D;R!A;GET:&EN9R!O;B!7
M:6YD;W=S(&)E8V%U<V4@;W5R('!A<F5N="!P<F]C97-S('=I;&P*("`@("`@
M("`C('1A:V4@8V%R92!O9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@("`@
M(&UY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*("`@("`@("`@("`@5$5-4$Q!
M5$4@/3X@)W1M<%A86%A8)RP*("`@("`@("`@("`@1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`H@("`@("`@("`@("!3549&25@@
M/3X@)RYC;60G+`H@("`@("`@("`@("!53DQ)3DL@/3X@,"P*("`@("`@("`I
M.PH*("`@("`@("!P<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;
M(%PD>"`M;'0@,3`@73L@9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@(&EF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@H@("`@("`@8G)E86L*("`@
M9FD*("`@<VQE97`@,0H@("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@
M+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W
M,#`L)'1M<"T^9FEL96YA;64["B`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I
M;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["B`@("`@("`@8VQO<V4@
M)'1M<#L*("`@("`@("!S>7-T96TH)&-M9"D["B`@("`@("`@;W5T<RAQ<2A3
M<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z
M("D*("`@("`@("`@("`@("X@)'1M<"T^9FEL96YA;64I.PH@("`@?0I]('T*
M"D)%1TE.('L*("`@($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE
M9"`F26YT97)N86QS.CI005(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN
M:71?96YV*"D["@II9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%
M3E9[4$%27T%21U9?,'T@*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?
M05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@
M/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%
M3E8I('L*("`@("`@("!D96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O
M.PH@("`@?0I]"@IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F
M:7@@)'!R;V=N86UE(&EF(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@
M/2`H"B`@("!P871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG
M(#H@)SHG*2P*("`@(%]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I
M;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@
M("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*
M7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T
M<FEN9R!C:&5C:VEN9R!A;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@
M>WM["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP
M92P@9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(
M+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*
M("`@(&UY("1B=68["B`@("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&
M2"P@)&)U9BP@.#L*("`@(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M
M7&XB.PH*("`@('-E96L@7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U
M9BP@-#L*("`@('-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@
M,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT
M96QL(%]&2"D@+2`T.PH@("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C
M:"!F:6QE(&EN=&\@;65M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*
M("`@('=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(
M+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*"B`@("`@("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@
M("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@
M("`@("`@;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]
M*2]\?"`I(#\@)#$@.B!U;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D
M97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@
M("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X
M="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@
M("`@("`@(&UY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L
M("1C<F,I.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@
M("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@
M)&)U9CL*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@
M("`@("!C:&UO9"`P-S4U+"`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@
M)&9I;&5N86UE.PH@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L
M<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2`I('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V
M960@=&\@7W1E;7!F:6QE*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@
M(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@("!O
M=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M
M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@
M(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*
M("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS
M92!["B`@("`@("`@("`@("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@
M("`@("`@("`@("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65]
M(#T@>PH@("`@("`@("`@("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@
M("`@("!C<F,@/3X@)&-R8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U
M;&QN86UE+`H@("`@("`@("`@("!].PH@("`@("`@('T*("`@("`@("!R96%D
M(%]&2"P@)&)U9BP@-#L*("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.
M0R`]("AS=6(@>PH@("`@("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*
M"B`@("`@("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*
M("`@("`@("!M>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD
M;6]D=6QE?2!\?"!D;R!["B`@("`@("`@("`@(&UY("1K97D["B`@("`@("`@
M("`@(&9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@
M("`@("`@;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@
M("`@("`D:V5Y(#T@)%\[(&QA<W0["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y
M*3L*("`@("`@("!](&]R(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE
M?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@
M*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI
M('L*("`@("`@("`@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE
M(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@
M("`@("!P<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@
M<V5E:R@D9F@L(#`L(#`I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@
M("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L("1N
M86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@
M("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E
M*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M
M/GMB=69].PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D
M:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@
M<F5T=7)N("1F:#L*("`@("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P
M<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@
M0$E.0RD["@H@("`@(R!.;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*
M"B`@("`C(&EN:71I86QI>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@
M("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@
M("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z
M.DAE879Y.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*
M("`@(",@;F]W(&QE="=S('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R
M;VT@=VET:&EN"B`@("!R97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R
M97-T(&]F('1H92!G<F]U<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C
M86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN
M,S(G.PH@("`@("`@('5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE
M;F%M92`]?B`O0E-$4$%.+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@;6]D
M=6QE<RP@9&\@;W1H97(@97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@("!I
M9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@("`@
M(')E<75I<F4@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<V4@>PH@("`@("`@("`@("`@("`@(R!3:VEP($%C=&EV95-T871E)W,@
M<VET96-U<W1O;6EZ92YP;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@)&9I
M;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L
M)"\["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@9&5L971E("1R
M97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@
M(&QA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T
M7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R
M;V-E<W-I;F<@>WM["FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L
M("1L;V=F:"P@)&-A8VAE7VYA;64I.PH*)'%U:65T(#T@,"!U;FQE<W,@)$5.
M5GM005)?1$5"54=].PH*(R!$;VXG="!S=V%L;&]W(&%R9W5M96YT<R!F;W(@
M8V]M<&EL960@97AE8W5T86)L97,@=VET:&]U="`M+7!A<BUO<'1I;VYS"FEF
M("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G
M("8F('-H:69T*2D@>PH@("`@;7D@)61I<W1?8VUD(#T@<7<H"B`@("`@("`@
M<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@:2`@(&EN<W1A;&Q?<&%R"B`@("`@
M("`@=2`@('5N:6YS=&%L;%]P87(*("`@("`@("!S("`@<VEG;E]P87(*("`@
M("`@("!V("`@=F5R:69Y7W!A<@H@("`@*3L*"B`@("!M>2!`861D7W1O7VEN
M8SL*("`@('=H:6QE("A`05)'5BD@>PH@("`@("`@("1!4D=66S!=(#U^("]>
M+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["@H@("`@("`@(&EF
M("@D,2!E<2`G22<I('L*("`@("`@("`@("`@<'5S:"!`861D7W1O7VEN8RP@
M)#(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G32<I('L*("`@
M("`@("`@("`@979A;"`B=7-E("0R(CL*("`@("`@("!]"B`@("`@("`@96QS
M:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@("`@("!U;G-H:69T($!P87)?87)G
M<RP@)#(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G3R<I('L*
M("`@("`@("`@("`@)&]U="`]("0R.PH@("`@("`@('T*("`@("`@("!E;'-I
M9B`H)#$@97$@)V(G*2!["B`@("`@("`@("`@("1B=6YD;&4@/2`G<VET92<[
M"B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G0B<I('L*("`@("`@
M("`@("`@)&)U;F1L92`]("=A;&PG.PH@("`@("`@('T*("`@("`@("!E;'-I
M9B`H)#$@97$@)W$G*2!["B`@("`@("`@("`@("1Q=6EE="`](#$["B`@("`@
M("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G3"<I('L*("`@("`@("`@("`@
M;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E
M;B!L;V<Z("0A(CL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=4
M)RD@>PH@("`@("`@("`@("`D8V%C:&5?;F%M92`]("0R.PH@("`@("`@('T*
M"B`@("`@("`@<VAI9G0H0$%21U8I.PH*("`@("`@("!I9B`H;7D@)&-M9"`]
M("1D:7-T7V-M9'LD,7TI('L*("`@("`@("`@("`@9&5L971E("1%3E9[)U!!
M4E]414U0)WT["B`@("`@("`@("`@(&EN:71?:6YC*"D["B`@("`@("`@("`@
M(')E<75I<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`F>R)005(Z.D1I<W0Z
M.B1C;60B?2@I('5N;&5S<R!`05)'5CL*("`@("`@("`@("`@)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*("`@("`@("`@("`@97AI=#L*
M("`@("`@("!]"B`@("!]"@H@("`@=6YS:&EF="!`24Y#+"!`861D7W1O7VEN
M8SL*?0H*(R!86%@@+2T@861D("TM<&%R+61E8G5G('-U<'!O<G0A"@HC('U]
M?0H*(R!/=71P=70@;6]D92`H+4\I(&AA;F1L:6YG('M[>PII9B`H)&]U="D@
M>PH@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,
M15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!)3SHZ
M1FEL93L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*"B`@
M("!M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PH@("`@;7D@)'II<#L*"@H@("`@
M:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L
M("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*("`@("`@
M("!B:6YM;V1E*"1F:"D["B`@("`@("`@8FQE<W,H)&9H+"`G24\Z.D9I;&4G
M*3L*"B`@("`@("`@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@("`@
M("@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I("D*("`@("`@("`@("`@;W(@9&EE(")296%D
M("<D<&%R)R!E<G)O<CH@)"$B.PH@("`@?0H*"B`@("!M>2`E96YV(#T@9&\@
M>PH@("`@("`@(&EF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E
M;G1S*"=-151!+GEM;"<I*2!["B`@("`@("`@("`@("1M971A(#U^(',O+BI>
M<&%R.B0O+VUS.PH@("`@("`@("`@("`D;65T82`]?B!S+UY<4RXJ+R]M<SL*
M("`@("`@("`@("`@)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PH@
M("`@("`@('T*("`@('T["@H@("`@(R!/<&5N(&EN<'5T(&%N9"!O=71P=70@
M9FEL97,@>WM["B`@("!L;V-A;"`D+R`](%PT.PH*("`@(&EF("AD969I;F5D
M("1P87(I('L*("`@("`@("!O<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B
M)"$Z("1P87(B.PH@("`@("`@(&)I;FUO9&4H4$%2*3L*("`@("`@("!D:64@
M(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<
M,#`S7#`P-"(["B`@("!]"@H@("`@0W)E871E4&%T:"@D;W5T*2`["B`@("`*
M("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<H"B`@("`@("`@)&]U="P*("`@
M("`@("!)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`H@("`@("`@(#`W-S<L"B`@("`I
M(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*"B`@("`D+R`]("AD969I
M;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["B`@("!S965K
M(%]&2"P@,"P@,#L*("`@(&UY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["B`@
M("!I9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_
M.B,A?%Q`<F5M*2\I('L*("`@("`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M;V13=')I<#L*("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^
M87!P;'DH7"1L;V%D97(L("0P*0H@("`@?0H@("`@9F]R96%C:"!M>2`D:V5Y
M("AS;W)T(&ME>7,@)65N=BD@>PH@("`@("`@(&UY("1V86P@/2`D96YV>R1K
M97E](&]R(&YE>'0["B`@("`@("`@)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L
M(#U^("]>6R<B72\["B`@("`@("`@;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B
M("X@=6,H)&ME>2D@+B`B7U\B.PH@("`@("`@(&UY("1S970@/2`B4$%27R(@
M+B!U8R@D:V5Y*2`N("(])'9A;"(["B`@("`@("`@)&QO861E<B`]?B!S>R1M
M86=I8R@@*RE]>PH@("`@("`@("`@("`D;6%G:6,@+B`D<V5T("X@*"<@)R!X
M("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*("`@("`@("!]96<["B`@
M("!]"B`@("`D9F@M/G!R:6YT*"1L;V%D97(I.PH@("`@)"\@/2!U;F1E9CL*
M("`@(",@?7U]"@H@("`@(R!7<FET92!B=6YD;&5D(&UO9'5L97,@>WM["B`@
M("!I9B`H)&)U;F1L92D@>PH@("`@("`@(')E<75I<F4@4$%2.CI(96%V>3L*
M("`@("`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["B`@("`@
M("`@:6YI=%]I;F,H*3L*"B`@("`@("`@<F5Q=6ER95]M;V1U;&5S*"D["@H@
M("`@("`@(&UY($!I;F,@/2!S;W)T('L*("`@("`@("`@("`@;&5N9W1H*"1B
M*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@
M("$O0E-$4$%.+PH@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("@D8G5N
M9&QE(&YE("=S:71E)RD@;W(*("`@("`@("`@("`@*"1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*("`@("`@("`@("`@("1?(&YE("1#
M;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["B`@("`@("`@?2!`24Y#.PH*
M("`@("`@("!I9B`H)$-O;F9I9WM?9&5L:6U](&5Q("=<7"<I('L@<WM<7'U[
M+WUG(&9O<B!`:6YC('T*"B`@("`@("`@(R!&:6QE(&5X:7-T<R!T97-T(&%D
M9&5D('1O(&9I>"!25"`C-#$W.3`Z"B`@("`@("`@(R!&=6YN>2P@;F]N+65X
M:7-T:6YG(&5N=')Y(&EN(%\\+BXN+F%U=&\O0V]M<')E<W,O4F%W+UIL:6(O
M875T;W-P;&ET+FEX+@H@("`@("`@(",@5&AI<R!I<R!A(&)A;F0M86ED(&9I
M>"!W:71H(&YO(&1E97!E<B!G<F%S<"!O9B!T:&4@:7-S=64N"B`@("`@("`@
M(R!3;VUE8F]D>2!P;&5A<V4@9V\@=&AR;W5G:"!T:&4@<&%I;B!O9B!U;F1E
M<G-T86YD:6YG('=H870G<R!H87!P96YI;F<L"B`@("`@("`@(R!)(&9A:6QE
M9"X@+2T@4W1E9F9E;@H@("`@("`@(&UY("5F:6QE<SL*("`@("`@("`O7E\\
M*"XK*20O(&%N9"`M92`D,2!A;F0@)&9I;&5S>R0Q?2LK(&9O<B!K97ES("4Z
M.CL*("`@("`@("`D9FEL97-[)%]]*RL@9F]R('9A;'5E<R`E24Y#.PH*("`@
M("`@("!M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*
M("`@("`@("!M>2`E=W)I='1E;CL*"B`@("`@("`@9F]R96%C:"`H<V]R="!K
M97ES("5F:6QE<RD@>PH@("`@("`@("`@("!M>2`H)&YA;64L("1F:6QE*3L*
M"B`@("`@("`@("`@(&9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PH@("`@("`@
M("`@("`@("`@:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M7WTI('L*("`@("`@("`@("`@("`@("`@("`D9FEL92`]("1?.PH@("`@("`@
M("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!E;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2![
M"B`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)#$L("0R
M*3L*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ
M6UY#8UTI7%HA*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&UY("1R968@
M/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@96QS:68@*"UF("(D9&ER+R0Q(BD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@B
M)&1I<B\D,2(L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)&YA
M;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*("`@("`@("`@("`@;F5X
M="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%
M)"\["B`@("`@("`@("`@(&]U=',H(&IO:6X@(B(L"B`@("`@("`@("`@("`@
M("!Q<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@
M)&9I;&4L"B`@("`@("`@("`@("`@("!Q<2@B+BXN*0H@("`@("`@("`@("`I
M.PH*("`@("`@("`@("`@;7D@)&-O;G1E;G0["B`@("`@("`@("`@(&EF("AR
M968H)&9I;&4I*2!["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]("1F:6QE
M+3Y[8G5F?3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@("`@(&]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A
M;B=T(&]P96X@)&9I;&4Z("0A(CL*("`@("`@("`@("`@("`@(&)I;FUO9&4H
M1DE,12D["B`@("`@("`@("`@("`@("`D8V]N=&5N="`](#Q&24Q%/CL*("`@
M("`@("`@("`@("`@(&-L;W-E($9)3$4["@H@("`@("`@("`@("`@("`@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4I"B`@("`@("`@("`@("`@("`@("`@:68@(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PH*("`@("`@("`@
M("`@("`@(",@1&\@;F]T(&QE="!84TQO861E<B!P:6-K('5P(&%U=&\O*B!F
M<F]M(&5N=FER;VYM96YT"B`@("`@("`@("`@("`@("`D8V]N=&5N="`]?B!S
M+V=O=&\@*W)E=')Y("MU;FQE<W,@*RXJ+V=O=&\@<F5T<GD[+PH@("`@("`@
M("`@("`@("`@("`@(&EF(&QC*"1N86UE*2!E<2!L8R@B6%-,;V%D97(N<&TB
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;W5T<RAQ<2A7<FET=&5N
M(&%S("(D;F%M92(I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@B1DE,12(I
M.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA
M;64I("L@.2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'-P<FEN=&8H"B`@
M("`@("`@("`@("`@("`B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T
M94-20S,R*"1C;VYT96YT*2P@)&YA;64*("`@("`@("`@("`@*2D["B`@("`@
M("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI
M*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@D8V]N=&5N="D["B`@("`@("`@
M?0H@("`@?0H@("`@(R!]?7T*"B`@("`C($YO=R!W<FET92!O=70@=&AE(%!!
M4B!A;F0@;6%G:6,@<W1R:6YG<R![>WL*("`@("1Z:7`M/G=R:71E5&]&:6QE
M2&%N9&QE*"1F:"D@:68@)'II<#L*"B`@("`D8V%C:&5?;F%M92`]('-U8G-T
M<B`D8V%C:&5?;F%M92P@,"P@-#`["B`@("!I9B`H(21C86-H95]N86UE(&%N
M9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*("`@("`@("!M>2`D
M8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!
M+3YN97<H,2D@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@
M?3L*"B`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI3
M2$$@-2XS."!A;F0@-2XS.0H@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V
M86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@(&EF
M("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G
M-2XS.2<I('L*("`@("`@("`@("`@)&-T>"T^861D9FEL92@D;W5T+"`B8B(I
M(&EF("@D8W1X*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@
M("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*("`@
M("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("1C
M='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1C86-H95]N86UE
M(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*("`@('T*("`@
M("1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PH@("`@)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*("`@("1F:"T^<')I
M;G0H)&-A8VAE7VYA;64I.PH@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H
M+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B`@("`D9F@M/G!R:6YT*")<
M;E!!4BYP;5QN(BD["B`@("`D9F@M/F-L;W-E.PH@("`@8VAM;V0@,#<U-2P@
M)&]U=#L*("`@(",@?7U]"@H@("`@97AI=#L*?0HC('U]?0H*(R!0<F5P87)E
M("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE(&-A8VAE('M[>PI["B`@("!L87-T
M('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["@H@("`@7V9I>%]P<F]G;F%M
M92@I.PH*("`@(",@3F]W(&QO860@=&AE(%!!4B!F:6QE(&%N9"!P=70@:70@
M:6YT;R!005(Z.DQI8D-A8VAE('M[>PH@("`@<F5Q=6ER92!005(["B`@("!0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H*("`@('L*("`@("`@
M("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@
M)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@1FEL93HZ1FEN9#L*("`@("`@
M("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*("`@(&UY("1Z:7`@/2!!
M<F-H:79E.CI::7`M/FYE=SL*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<[
M"B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A
M.B`D0"(["B`@("`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O
M9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D
M0"(["@H@("`@<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*("`@("1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PH*("`@("1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["B`@("!O=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]
M("(D14Y6>U!!4E]414U0?2(I*3L*"B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*("`@
M("`@("!F;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PH@
M("`@("`@("`@("!N97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PH@("`@
M("`@("`@("!M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M("`@("`@("`@("`@;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["B`@
M("`@("`@("`@("`@("!>"B`@("`@("`@("`@("`@("`O/W-H;&EB+PH@("`@
M("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B`@
M("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_
M"B`@("`@("`@("`@("`@("`H6UXO72LI"B`@("`@("`@("`@("`@("`D"B`@
M("`@("`@("`@('UX.PH@("`@("`@("`@("!M>2`D97AT<F%C=%]N86UE(#T@
M)#$["B`@("`@("`@("`@(&UY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC
M871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*("`@("`@
M("`@("`@:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU
M;F-O;7!R97-S9613:7IE*"DI('L*("`@("`@("`@("`@("`@(&]U=',H<7$H
M4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES
M=',@870@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("!O=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M
M92(@=&\@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@("`@("`D;65M8F5R
M+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["B`@("`@("`@("`@
M("`@("!C:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*?0HC
M('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N+"!S:&]W('5S
M86=E('M[>PIU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*
M("`@(&1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI
M8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@
M<')O9W)A;2YP;"!="B`@("`@("`D,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@
M<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@
M/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R96%T95!A=&@@
M>PH@("`@;7D@*"1N86UE*2`]($!?.PH@("`@"B`@("!R97%U:7)E($9I;&4Z
M.D)A<V5N86UE.PH@("`@;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@
M1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PH@
M("`@"B`@("!R97%U:7)E($9I;&4Z.E!A=&@["B`@("`*("`@($9I;&4Z.E!A
M=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@
M9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L97,@>PH@("`@
M(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-
M4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI8CL*("`@(')E<75I<F4@1'EN84QO
M861E<CL*("`@(')E<75I<F4@:6YT96=E<CL*("`@(')E<75I<F4@<W1R:6-T
M.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*("`@(')E<75I<F4@=F%R<SL*("`@
M(')E<75I<F4@0V%R<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R
M97%U:7)E($5R<FYO.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@
M("!R97%U:7)E($5X<&]R=&5R.PH@("`@<F5Q=6ER92!&8VYT;#L*("`@(')E
M<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@
M(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E($-O;F9I9SL*("`@(')E
M<75I<F4@24\Z.DAA;F1L93L*("`@(')E<75I<F4@24\Z.D9I;&4["B`@("!R
M97%U:7)E($-O;7!R97-S.CI:;&EB.PH@("`@<F5Q=6ER92!!<F-H:79E.CI:
M:7`["B`@("!R97%U:7)E(%!!4CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*
M("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["B`@("!E=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@(&5V
M86P@>R!R97%U:7)E(%=I;C,R('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L
M87(Z.E5T:6P@?3L*("`@(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP
M.CI"=7)S="!].PH@("`@979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE
M9$-A<'1U<F4@?3L*?0H*(R!4:&4@0R!V97)S:6]N(&]F('1H:7,@8V]D92!A
M<'!E87)S(&EN(&UY;&1R+VUK=&UP9&ER+F,*(R!4:&ES(&-O9&4@86QS;R!L
M:79E<R!I;B!005(Z.E-E='5P5&5M<"!A<R!S971?<&%R7W1E;7!?96YV(0IS
M=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B`@("`@("`@
M)'!A<E]T96UP(#T@)#$["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&9O
M<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@("AM87`@)$5.5GLD7WTL('%W*"!0
M05)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`H@("`@("`@
M('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@("`@*2!["B`@("`@("`@;F5X="!U
M;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H
M.PH@("`@("`@(&UY("1U<V5R;F%M93L*("`@("`@("!M>2`D<'=U:60["B`@
M("`@("`@(R!D;V5S(&YO="!W;W)K(&5V97)Y=VAE<F4Z"B`@("`@("`@979A
M;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PH*
M("`@("`@("!I9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PH@
M("`@("`@("`@("`D=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*("`@
M("`@("!]"B`@("`@("`@96QS:68@*&1E9FEN960@)'!W=6ED*2!["B`@("`@
M("`@("`@("1U<V5R;F%M92`]("1P=W5I9#L*("`@("`@("!]"B`@("`@("`@
M96QS92!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1%3E9[55-%4DY!345]
M('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["B`@("`@("`@?0H@("`@("`@
M("1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*"B`@("`@("`@;7D@)'-T;7!D:7(@
M/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M)'5S97)N86UE(CL*("`@("`@
M("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!I9B`H(21%3E9[4$%2
M7T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI
M('L*("`@("`@("`@("`@;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D[
M"B`@("`@("`@("`@('-E96L@)&9H+"`M,3@L(#(["B`@("`@("`@("`@('-Y
M<W)E860@)&9H+"!M>2`D8G5F+"`V.PH@("`@("`@("`@("!I9B`H)&)U9B!E
M<2`B7#!#04-(12(I('L*("`@("`@("`@("`@("`@('-E96L@)&9H+"`M-3@L
M(#(["B`@("`@("`@("`@("`@("!S>7-R96%D("1F:"P@)&)U9BP@-#$["B`@
M("`@("`@("`@("`@("`D8G5F(#U^(',O7#`O+V<["B`@("`@("`@("`@("`@
M("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@
M("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I
M9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@
M?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@("`@("`@("`@
M(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@
M-2XS.0H@("`@("`@("`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![
M("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@("`@("`@
M("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@
M97$@)S4N,SDG*2!["B`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL
M92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M
M/FAE>&1I9V5S="`Z("1M=&EM92`I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&-L;W-E*"1F:"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`Q.PH@("`@("`@("`@("`D<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["B`@("`@("`@?0H*
M("`@("`@("`D14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PH@("`@("`@(&UK
M9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&QA<W0["B`@("!]"@H@("`@
M)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%2
M7U1%35!](#U^("\H+BLI+SL*?0H*<W5B(%]T96UP9FEL92!["B`@("!M>2`H
M)&5X="P@)&-R8RD@/2!`7SL*("`@(&UY("@D9F@L("1F:6QE;F%M92D["@H@
M("`@)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["@H@("`@:68@
M*"1%3E9[4$%27T-,14%.?2D@>PH@("`@("`@('5N;&EN:R`D9FEL96YA;64@
M:68@+64@)&9I;&5N86UE.PH@("`@("`@('!U<V@@0'1M<&9I;&4L("1F:6QE
M;F%M93L*("`@('T*("`@(&5L<V4@>PH@("`@("`@(')E='5R;B`H=6YD968L
M("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M92D["B`@("!]"@H@("`@;W!E
M;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H
M)&9H*3L*("`@(')E='5R;B@D9F@L("1F:6QE;F%M92D["GT*"B,@<V%M92!C
M;V1E(&QI=F5S(&EN(%!!4CHZ4V5T=7!0<F]G;F%M93HZ<V5T7W!R;V=N86UE
M"G-U8B!?<V5T7W!R;V=N86UE('L*("`@(&EF("AD969I;F5D("1%3E9[4$%2
M7U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@
M>PH@("`@("`@("1P<F]G;F%M92`]("0Q.PH@("`@?0H*("`@("1P<F]G;F%M
M92!\?#T@)#`["@H@("`@:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B`@("`@("`@)'!R
M;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@("`@?0H*("`@(&EF("@A)$5.5GM0
M05)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`^/2`P*2!["B`@("`@("`@:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PH@("`@("`@("`@("!R971U<FX@:68@+7,@)&9H.PH@("`@
M("`@('T*("`@("`@("!I9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2!["B`@("`@("`@("`@("1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PH@
M("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@?0H*("`@(&9O<F5A
M8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%
M3E9[4$%42'TI('L*("`@("`@("!N97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]4
M14U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*("`@("`@("`D9&ER
M(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*("`@("`@("`H*"1P<F]G
M;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?
M97AE?2(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PH@("`@("`@("@H)'!R
M;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S
M="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I>%]P<F]G;F%M92!["B`@("`D,"`]
M("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PH@("`@:68@*&EN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*("`@("`@
M("`D<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@
M("!]"@H@("`@(R!86%@@+2!H86-K('1O(&UA:V4@4%=$('=O<FL*("`@(&UY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0H@("`@("`@("`@("`@("`@.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I
M(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PH@("`@8VAO;7`H)'!W9"D[
M"B`@("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM
M?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*"B`@("`D14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64["GT*"G-U8B!?<&%R7VEN:71?96YV('L*("`@
M(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*("`@("`@
M("!R971U<FX["B`@("!](&5L<V4@>PH@("`@("`@("1%3E9[4$%27TE.251)
M04Q)6D5$?2`](#(["B`@("!]"@H@("`@9F]R("AQ=R@@4U!!5TY%1"!414U0
M($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2![
M"B`@("`@("`@9&5L971E("1%3E9[)U!!4E\G+B1??3L*("`@('T*("`@(&9O
M<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*("`@("`@("`D
M14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X
M:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PH@("`@?0H*("`@(&UY("1P
M87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B
M.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2D@>PH@("`@("`@(&1E;&5T92`D
M14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@("!E;'-I9B`H(65X:7-T<R`D14Y6
M>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@("`@("`@;7D@)'9A;'5E(#T@<W5B
M<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*("`@("`@
M("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%
M04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@;W5T<R!["B`@("!R971U<FX@:68@
M)'%U:65T.PH@("`@:68@*"1L;V=F:"D@>PH@("`@("`@('!R:6YT("1L;V=F
M:"`B0%]<;B(["B`@("!]"B`@("!E;'-E('L*("`@("`@("!P<FEN="`B0%]<
M;B(["B`@("!]"GT*"G-U8B!I;FET7VEN8R!["B`@("!R97%U:7)E($-O;F9I
M9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ
M0V]N9FEG>R1??2P@<7<H"B`@("`@("`@87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*("`@("`@("!V96YD;W)A<F-H97AP
M('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G92!F;W(@<V-R:7!T(&5X96-U=&EO
M;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@
M7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PH*9&EE
M('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE
M(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0H@("`@=6YL97-S("UE
M("1P<F]G;F%M93L*"F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@
M*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PH*
M?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0H*0T]213HZ97AI="@D,2D@
M:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PH*,3L*"B-L:6YE(#$P,#(*"E]?
M14Y$7U\*`````1L#.S`````%````H)___TP```#@G___:````/"?__^$````
M4*#__Z0```"0H/__P````!0``````````7I2``%\"`$;#`0$B`$``!@````<
M````3)___SL`````00X(0H4"#05,@P,8````.````'"?__\%`````$$."$*%
M`@T%````'````%0```!DG___6@````!!#@A"A0(-!4Z#!88$AP,8````=```
M`*2?__\R`````$$."$*%`@T%4H,#&````)````#(G___,@````!!#@A"A0(-
M!5*#`P````#_____`````/____\```````````$````!`````0```*T"```!
M````O`(```$```#(`@```0```-,"```!````W0(```$```#K`@```0```/@"
M```!````1P,```\```"!!```#`````B4!`@-````+-L$"/7^_V^,@00(!0``
M``2*!`@&````Y(($"`H````8!@``"P```!`````5``````````,````X3`4(
M`@```'`"```4````$0```!<```"8D00($0```("1!`@2````&````!,````(
M````_O__;P"1!`C___]O`@```/#__V\<D`0(````````````````````````
M`````````````````````````````````````````````"1+!0@`````````
M`$Z4!`A>E`0(;I0$"'Z4!`B.E`0(GI0$"*Z4!`B^E`0(SI0$"-Z4!`CNE`0(
M_I0$"`Z5!`@>E00(+I4$"#Z5!`A.E00(7I4$"&Z5!`A^E00(CI4$")Z5!`BN
ME00(OI4$",Z5!`C>E00([I4$"/Z5!`@.E@0('I8$""Z6!`@^E@0(3I8$"%Z6
M!`ANE@0(?I8$"(Z6!`B>E@0(KI8$"+Z6!`C.E@0(WI8$".Z6!`C^E@0(#I<$
M"!Z7!`@NEP0(/I<$"$Z7!`A>EP0(;I<$"'Z7!`B.EP0(GI<$"*Z7!`B^EP0(
MSI<$"-Z7!`CNEP0(_I<$"`Z8!`@>F`0(+I@$"#Z8!`A.F`0(7I@$"&Z8!`A^
MF`0(CI@$")Z8!`BNF`0(OI@$",Z8!`C>F`0([I@$"/Z8!`@.F00('ID$"```
M``"EVP0(I]L$"/____^@X`0(;5D```!'0T,Z("A'3E4I(#0N-"XP(#(P,#DP
M-3`V("A2960@2&%T(#0N-"XP+30I``!'0T,Z("A'3E4I(#0N-"XP(#(P,#DP
M-3`V("A2960@2&%T(#0N-"XP+30I``!'0T,Z("A'3E4I(#0N-"XP(#(P,#DP
M-3`V("A2960@2&%T(#0N-"XP+30I``!'0T,Z("A'3E4I(#0N-"XP(#(P,#DP
M-3`V("A2960@2&%T(#0N-"XP+30I``!'0T,Z("A'3E4I(#0N-"XP(#(P,#DP
M-3`V("A2960@2&%T(#0N-"XP+30I``!'0T,Z("A'3E4I(#0N-"XP(#(P,#DP
M-3`V("A2960@2&%T(#0N-"XP+30I``!'0T,Z("A'3E4I(#0N-"XP(#(P,#DP
M-3`V("A2960@2&%T(#0N-"XP+30I```N<VAS=')T86(`+FEN=&5R<``N;F]T
M92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y
M;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y
M;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M
M95]H9'(`+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`+FIC<@`N9'EN86UI8P`N
M9V]T`"YG;W0N<&QT`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````
M```````````````````````````````````````+`````0````(````T@00(
M-`$``!,```````````````$`````````$P````<````"````2($$"$@!```@
M```````````````$`````````"$````'`````@```&B!!`AH`0``)```````
M````````!``````````T````]O__;P(```",@00(C`$``%@!```%````````
M``0````$````/@````L````"````Y(($".0"```@!P``!@````$````$````
M$````$8````#`````@````2*!`@$"@``&`8``````````````0````````!.
M````____;P(````<D`0('!```.0````%``````````(````"````6P```/[_
M_V\"`````)$$"``1``"`````!@````(````$`````````&H````)`````@``
M`("1!`B`$0``&`````4`````````!`````@```!S````"0````(```"8D00(
MF!$``'`"```%````#`````0````(````?`````$````&````")0$"`@4```P
M```````````````$`````````'<````!````!@```#B4!`@X%```\`0`````
M````````!`````0```""`````0````8````PF00(,!D``/Q!````````````
M`!``````````B`````$````&````+-L$""Q;```<```````````````$````
M`````(X````!`````@```&#;!`A@6P``SEX`````````````(`````````"6
M`````0````(````P.@4(,+H``#0```````````````0`````````I`````$`
M```"````9#H%"&2Z``"L```````````````$`````````*X````!`````P``
M`!!+!0@0NP``"```````````````!`````````"U`````0````,````82P4(
M&+L```@```````````````0`````````O`````$````#````($L%"""[```$
M```````````````$`````````,$````&`````P```"1+!0@DNP``$`$```8`
M````````!`````@```#*`````0````,````T3`4(-+P```0`````````````
M``0````$````SP````$````#````.$P%"#B\``!$`0`````````````$````
M!````-@````!`````P```'Q-!0A\O0``&```````````````!`````````#>
M````"`````,```"@304(E+T``$00`````````````"``````````XP````$`
M`````````````)2]```[`0`````````````!``````````$````#````````
=``````#/O@``[````````````````0``````````
